@@ -12,7 +12,7 @@
 #include "config/globalconf.h"
 
 #include "cache.h"
-#include "global.h"
+#include "type.h"
 
 CORE::AAManager* instance_aamanager = NULL;
 
@@ -59,8 +59,6 @@ AAManager::~AAManager()
 #ifdef _DEBUG
     std::cout << "AAManager::~AAManager\n";
 #endif
-
-    save_history();
 }
 
 
