@@ -9,6 +9,8 @@
 
 #include "skeleton/msgdiag.h"
 
+#include "message/messageadmin.h"
+
 #include "dbtree/interface.h"
 #include "dbtree/articlebase.h"
 
@@ -36,6 +38,7 @@ using namespace ARTICLE;
 
 enum
 {
+    CANCEL_RELOAD = 500,  // msec  連続リロード防止用カウンタ
     LIVE_SEC_PLUS = 5, // 実況で更新失敗/成功ごとに増減する更新間隔(秒)
     LIVE_MAX_RELOAD = 5  // 実況でこの回数連続でリロードに失敗したら実況停止
 };
@@ -44,7 +47,7 @@ enum
 // メインビュー
 
 ArticleViewMain::ArticleViewMain( const std::string& url )
-    :  ArticleViewBase( url ), m_gotonum_reserve_to( 0 ), m_gotonum_reserve_from( 0 ), m_gotonum_seen( 0 ), m_playsound( false ), m_reload_reserve( false )
+    :  ArticleViewBase( url, url ), m_gotonum_reserve_to( 0 ), m_gotonum_reserve_from( 0 ), m_gotonum_seen( 0 ), m_playsound( false ), m_reload_reserve( false ), m_cancel_reload_counter( 0 )
 {
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::ArticleViewMain " << get_url() << " url_article = " << url_article() << std::endl;
@@ -71,13 +74,8 @@ ArticleViewMain::~ArticleViewMain()
 #ifdef _DEBUG    
     std::cout << "ArticleViewMain::~ArticleViewMain : " << get_url() << " url_article = " << url_article() << std::endl;
 #endif
-    const int seen = drawarea()->get_seen_current();
-        
-#ifdef _DEBUG    
-    std::cout << "set seen to " << seen << std::endl;
-#endif
 
-    if( seen >= 1 ) get_article()->set_number_seen( seen );
+    save_session();
 
     // 閉じたタブ履歴更新
     HISTORY::append_history( URL_HISTCLOSEVIEW,
@@ -90,6 +88,18 @@ ArticleViewMain::~ArticleViewMain()
 }
 
 
+void ArticleViewMain::save_session()
+{
+    const int seen = drawarea()->get_seen_current();
+        
+#ifdef _DEBUG    
+    std::cout << "set seen to " << seen << std::endl;
+#endif
+
+    if( seen >= 1 ) get_article()->set_number_seen( seen );
+}
+
+
 // virtual
 void ArticleViewMain::clock_in()
 {
@@ -108,6 +118,8 @@ void ArticleViewMain::clock_in()
             show_view();
         }
     }
+
+    if( m_cancel_reload_counter ) --m_cancel_reload_counter;
 }
 
 
@@ -220,6 +232,28 @@ void ArticleViewMain::show_view()
     }
 
     if( is_loading() ) return;
+    if( m_cancel_reload_counter ){
+#ifdef _DEBUG
+        std::cout << "cancel reload\n";
+#endif
+        return;
+    }
+
+    // キャッシュを削除してからスレを再読み込み
+    if( SESSION::is_online() && get_reget() ){
+
+        int jump_to = drawarea()->get_seen_current();
+        if( ! jump_to ) jump_to = get_article()->get_number_seen();
+
+#ifdef _DEBUG
+        std::cout << "ArticleViewMain::show_view reget url_article = " << url_article()
+                  << " jump_to = " << jump_to << std::endl;
+#endif
+
+        set_reget( false );
+        CORE::core_set_command( "delete_article", url_article(), "reget", MISC::itostr( jump_to ) );        
+        return;
+    }
 
     m_gotonum_reserve_to = 0;
     m_gotonum_reserve_from = 0;
@@ -233,7 +267,7 @@ void ArticleViewMain::show_view()
     reset_autoreload_counter();
 
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::show_view\n";
+    std::cout << "ArticleViewMain::show_view " << url_article() << std::endl;
 #endif
 
     if( get_url().empty() ){
@@ -335,6 +369,9 @@ void ArticleViewMain::show_view()
 
         // タブのアイコン状態を更新
         ARTICLE::get_admin()->set_command( "toggle_icon", get_url() );
+
+        // スレ一覧などを素早くクリックした時などに2回リロードされるのを防ぐ
+        m_cancel_reload_counter = CANCEL_RELOAD / TIMER_TIMEOUT;
     }
 }
 
@@ -430,8 +467,11 @@ void ArticleViewMain::update_finish()
     if( ! number_new ) drawarea()->hide_separator_new();
 
     // ステータス更新 (実況中はフォーカスされてなくても表示)
+    std::string force;
+    if( get_live() ) force = "force";
     create_status_message();
-    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status(), ( get_live() ? "force" : "" ) );
+    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status(), force );
+    ARTICLE::get_admin()->set_command( "set_status_color", get_url(), get_color(), force );
 
     // タイトルセット
     set_title( DBTREE::article_subject( url_article() ) );
@@ -457,7 +497,7 @@ void ArticleViewMain::update_finish()
     }
 
     // ロード後に末尾ジャンプ
-    else if( CONFIG::get_jump_after_reload() && number_new ){
+    else if( ! get_live() && CONFIG::get_jump_after_reload() && number_new ){
 #ifdef _DEBUG
         std::cout << "jump_after_reload\n";
 #endif
@@ -465,7 +505,7 @@ void ArticleViewMain::update_finish()
     }
 
     // ロード後に新着へジャンプ
-    else if( CONFIG::get_jump_new_after_reload() && number_new ){
+    else if( ! get_live() && CONFIG::get_jump_new_after_reload() && number_new ){
 #ifdef _DEBUG
         std::cout << "jump_new_after_reload\n";
 #endif
@@ -505,7 +545,15 @@ void ArticleViewMain::update_finish()
             set_autoreload_sec( MAX( live_sec, get_autoreload_sec() - LIVE_SEC_PLUS ) );
 
             // messageビューが出ているときはフォーカスを移す
-            CORE::core_set_command( "switch_message" );
+            if( ! MESSAGE::get_admin()->empty() ){
+                // 実況モードかつポップアップが表示されている状態で、 "switch_message" コマンドを発行すると、
+                // 埋め込みメッセージモードだと、 MessageAdmin に対して "focus_current_view" されるので、
+                // ArticleView に focus_out イベントが発生して、ポップアップが消えてしまう
+                // ポップアップが表示されているときは、フォーカスを移さない
+                if( ! is_popup_shown() ){
+                    CORE::core_set_command( "switch_message" );
+                }
+            }
         }
 
         drawarea()->update_live_speed( get_autoreload_sec() );
