@@ -14,7 +14,8 @@ namespace ARTICLE
     class ArticleViewMain : public ArticleViewBase
     {
         // ジャンプ予約, goto_num() のコメント参照
-        int m_gotonum_reserve; 
+        int m_gotonum_reserve_to; 
+        int m_gotonum_reserve_from; 
 
         int m_gotonum_seen; // 前回見ていた場所へのジャンプ用
 
@@ -26,15 +27,23 @@ namespace ARTICLE
 
         bool m_show_closedialog;
 
+        bool m_reload_reserve;
+
+        // 連続リロード防止用
+        int m_cancel_reload_counter;
+
       public:
         ArticleViewMain( const std::string& url );
         ~ArticleViewMain();
 
         virtual void clock_in();
 
-        virtual void goto_num( int num );
+        virtual void goto_num( const int num_to, const int num_from );
 
         // SKELETON::View の関数のオーバロード
+
+        virtual void save_session();
+
         virtual const bool is_loading();
         virtual const bool is_updated();
         virtual const bool is_check_update();
