@@ -50,12 +50,16 @@ namespace ARTICLE
         // slot呼び出し時にURLのやりとりに使う一時変数
         std::string m_url_tmp; // url
         std::string m_str_num; // レス番号
+        std::string m_jump_to; // ジャンプ先番号
+        std::string m_jump_from; // ジャンプ元番号
         std::string m_id_name; // ID
         std::string m_name;    // 名前
 
         // ポップアップ
         SKELETON::PopupWin* m_popup_win;
         bool m_popup_shown; // 表示されているならtrue, falseでもdeleteしない限りは m_popup_win != NULLに注意
+        int m_hidepopup_counter; // ポップアップを消すまでのカウンタ
+        std::string m_popup_url; // 表示中のポップアップのアドレス
 
         // 検索用
         bool m_search_invert; // 逆方向検索モード
@@ -67,6 +71,9 @@ namespace ARTICLE
         // ブックマーク移動時の現在の位置(レス番号)
         int m_current_bm;
 
+        // 書き込みマーク移動時の現在の位置(レス番号)
+        int m_current_post;
+
         // 抽出ビューで荒らし報告用のURLを表示する
         bool m_show_url4report;
 
@@ -79,16 +86,23 @@ namespace ARTICLE
         // ライブモードか
         bool m_live;
 
+        // メニューのユーザコマンド、 create_usrcmd_menu() で作成
+        std::string m_usrcmd;
+
     public:
 
-        ArticleViewBase( const std::string& url );
+        ArticleViewBase( const std::string& url, const std::string& url_article );
         virtual ~ArticleViewBase();
 
         const std::string& url_article() const { return m_url_article; }
-        virtual const std::string url_for_copy();
+
         const std::string& get_label_board(){ return m_label_board; }
 
         // SKELETON::View の関数のオーバロード
+
+        virtual void save_session(){}        
+
+        virtual const std::string url_for_copy(); // コピーやURLバー表示用のURL
         virtual const int width_client();
         virtual const int height_client();
         virtual const int get_icon( const std::string& iconname );
@@ -100,6 +114,9 @@ namespace ARTICLE
         virtual void clock_in();
         void clock_in_smooth_scroll();
 
+        // キーを押した
+        virtual const bool slot_key_press( GdkEventKey* event );
+
         virtual void write();
         virtual void reload();
         virtual void stop();
@@ -112,7 +129,7 @@ namespace ARTICLE
         virtual const bool operate_view( const int control );
         virtual void goto_top();
         virtual void goto_bottom();
-        virtual void goto_num( int num );
+        virtual void goto_num( const int num_to, const int num_from );
         virtual void show_preference();
 
         // 進む、戻る
@@ -135,12 +152,13 @@ namespace ARTICLE
         // 実況モードか
         const bool get_live() const { return m_live; }
 
+        DrawAreaBase* drawarea();
+
     protected:
 
         // Viewが所属するAdminクラス
         virtual SKELETON::Admin* get_admin();
 
-        DrawAreaBase* drawarea();
         JDLIB::RefPtr_Lock< DBTREE::ArticleBase >& get_article();
 
         // ポップアップメニューを表示する前にメニューのアクティブ状態を切り替える
@@ -150,7 +168,10 @@ namespace ARTICLE
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
 
         // レスポップアップを隠す
-        void hide_popup( bool force = false );
+        void hide_popup( const bool force = false );
+
+        // ポップアップが表示されているか
+        const bool is_popup_shown() const;
 
         // 初期設定
         void setup_view();
@@ -161,7 +182,7 @@ namespace ARTICLE
         // レスを抽出して表示
         // num は "from-to"　の形式 (例) 3から10を抽出したいなら "3-10"
         // show_title == trueの時は 板名、スレ名を表示
-        void show_res( const std::string& num, bool show_title );
+        void show_res( const std::string& num, const bool show_title );
 
         // 名前 で抽出して表示
         // show_option = true の時は URL 表示などのオプションが表示される
@@ -169,7 +190,7 @@ namespace ARTICLE
 
         // ID で抽出して表示
         // show_option = true の時は URL 表示などのオプションが表示される
-        void show_id( const std::string& id_name, bool show_option );
+        void show_id( const std::string& id_name, const bool show_option );
 
         // ブックマークを抽出して表示
         void show_bm();
@@ -202,10 +223,10 @@ namespace ARTICLE
         virtual void append_dat( const std::string& dat, int num );
 
         // リストで指定したレスを表示
-        void append_res( std::list< int >& list_resnum );
+        void append_res( const std::list< int >& list_resnum );
 
         // リストで指定したレスを表示(連結情報付き)
-        void append_res( std::list< int >& list_resnum, std::list< bool >& list_joint );
+        void append_res( const std::list< int >& list_resnum, const std::list< bool >& list_joint );
 
         // 画像プロパティ表示
         void slot_preferences_image();
@@ -224,40 +245,42 @@ namespace ARTICLE
         virtual DrawAreaBase* create_drawarea();        
 
         void setup_action();
-        const std::string create_usrcmd_menu();
-        const std::string create_usrcmd_menu( XML::Dom* dom, int& dirno, int& cmdno );
+
+        // 通常の右クリックメニューの作成
+        const std::string create_context_menu();
+        const char* get_menu_item( const int item );
 
         virtual void exec_reload();
+        void reload_article();
+
         void exec_delete();
 
         // 荒らし報告用のURLリストをHTML形式で取得
-        std::string get_html_url4report( std::list< int >& list_resnum );
+        const std::string get_html_url4report( const std::list< int >& list_resnum );
         
         // drawarea の signal を受け取る slots
         virtual bool slot_button_press( std::string url, int res_number, GdkEventButton* event );
         bool slot_button_release( std::string url, int res_number, GdkEventButton* event );
         bool slot_motion_notify( GdkEventMotion* event );
-        const bool slot_key_press( GdkEventKey* event );
         bool slot_key_release( GdkEventKey* event );
         bool slot_scroll_event( GdkEventScroll* event );
         bool slot_leave_notify( GdkEventCrossing* ev );
 
         // レスポップアップ関係
 
-        // ポップアップが表示されているか
-        const bool is_popup_shown() const;
-
         // ポップアップが表示されていてかつマウスがその上にあるか
         const bool is_mouse_on_popup();
 
-        void show_popup( SKELETON::View* view, int margin );
+        void show_popup( SKELETON::View* view, const int mrg_x, const int mrg_y );
         bool slot_popup_leave_notify_event( GdkEventCrossing* event );
         void slot_hide_popup();
         void delete_popup(); // ポップアップ強制削除
         void warp_pointer_to_popup(); // マウスポインタをポップアップの上に移動する
         
         void slot_bookmark();
+        void slot_postedmark();
         void slot_open_browser();
+        void slot_open_cache_browser();
         void slot_write_res();
         void slot_quote_res();
         void slot_quote_selection_res();
@@ -272,6 +295,7 @@ namespace ARTICLE
         void slot_search_title();
         void slot_usrcmd( int num );
         void slot_copy_res( bool ref );
+        void slot_copy_title_url();
         void slot_drawout_res();
         void slot_drawout_around();
         void slot_drawout_tmp();
@@ -282,6 +306,7 @@ namespace ARTICLE
         void slot_drawout_refer();
         void slot_drawout_url();
         void slot_abone_res();
+        void slot_abone_selection_res();
         void slot_abone_id();
         void slot_abone_name();
         void slot_abone_word();
@@ -293,17 +318,30 @@ namespace ARTICLE
         void slot_toggle_abone_transp_chain();
         void slot_pre_bm();
         void slot_next_bm();
+        void slot_pre_post();
+        void slot_next_post();
         void slot_jump();
         void slot_save_dat();
         void slot_copy_article_info();
 
+        // あぼーん設定
+        void slot_setup_abone();
+        void slot_setup_abone_board();
+        void slot_setup_abone_all();
+
         // リンクの処理
-        virtual void slot_on_url( std::string url, int res_number );
+        virtual void slot_on_url( std::string url, std::string imgurl, int res_number );
         void slot_leave_url();
         bool click_url( std::string url, int res_number, GdkEventButton* event );
+        void open_image( const std::string& url, const int res_number,
+                         const bool open_imageview, const bool open_browser, const bool mosaic, const bool switch_image );
 
         // 画像ポップアップメニュー用
         void slot_cancel_mosaic();
+        void slot_show_image_with_mosaic();
+        void slot_show_selection_images();
+        void slot_delete_selection_images();
+        void slot_abone_selection_images();
         void slot_show_large_img();
         void slot_deleteimage();
         void slot_toggle_protectimage();
