@@ -152,7 +152,7 @@ void ArticleViewSearch::update_label()
 {
     std::string label;
     if( m_searchmode == CORE::SEARCHMODE_TITLE ) label =  "スレタイ検索";
-    if( m_searchmode == CORE::SEARCHMODE_ALLLOG ) label =  "全ログ検索";
+    else if( m_searchmode == CORE::SEARCHMODE_ALLLOG ) label =  "全ログ検索";
     else label = "ログ検索";
     if( ! get_search_query().empty() ) label += " ： " + get_search_query();
     set_label( label );
@@ -290,7 +290,7 @@ void ArticleViewSearch::relayout()
                 if( m_searchmode == CORE::SEARCHMODE_ALLLOG || m_searchmode == CORE::SEARCHMODE_TITLE  )
                     comment << "[ <a href=\"" << DBTREE::url_subject( (*it).url_readcgi ) << "\">" << (*it).boardname << "</a> ] ";
 
-                comment << "<a href=\"" << (*it).url_readcgi << "\">" << (*it).subject << "</a>";
+                comment << "<a href=\"" << (*it).url_readcgi << "\">" << MISC::html_escape( (*it).subject ) << "</a>";
 
                 if( (*it).num ) comment << " ( " << (*it).num << " )";
 
