@@ -570,6 +570,8 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
     else if( command == "check_update_open_root" ) check_update_dir( true, true );
     else if( command == "cancel_check_update" ) stop();
 
+    else if( command == "select_item" ) select_item( arg1 );
+
     return true;
 }
 
@@ -2507,6 +2509,68 @@ void BBSListViewBase::toggle_boardicon( const std::string& url )
 
 
 
+//
+// URLを選択
+//
+void BBSListViewBase::select_item( const std::string& url )
+{
+    if( ! m_ready_tree ) return;
+    if( m_treestore->children().empty() ) return;
+
+    std::string url_item( url );
+
+    if( m_set_thread.find_if( url_item )
+            || m_set_image.find( url_item ) != m_set_image.end()){
+        // スレまたは画像の場合
+    }
+    else {
+        // 板の場合
+        url_item = DBTREE::url_boardbase( url );
+
+        // 未登録の画像などで、板が見つからない場合は処理しない
+        if( url_item.empty() ) return;
+    }
+
+    Gtk::TreePath closed_path;
+    int closed_found = false;
+
+    SKELETON::EditTreeViewIterator it( m_treeview, m_columns, Gtk::TreePath() );
+    for( ; ! it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *it;
+        const Glib::ustring url_row = row[ m_columns.m_url ];
+
+        if( url_item == url_row ){
+            // 最初に見つかったものにフォーカスする
+            Gtk::TreePath path = GET_PATH( row );
+
+            if( m_treeview.is_expand( path ) ){
+                // 開いているエントリ
+                m_treeview.get_selection()->unselect_all();
+                m_treeview.set_cursor( path );
+
+                return;
+            }
+
+            // 最初の閉じたエントリを覚えておく
+            if( ! closed_found ){
+                closed_found = true;
+                closed_path = path;
+            }
+        }
+    }
+
+    // 開いたエントリが見つからない
+    if( closed_found && CONFIG::get_select_item_sync() == 2 ){
+        // 閉じたエントリの上位フォルダを開いてフォーカスする
+        m_treeview.get_selection()->unselect_all();
+        m_treeview.expand_parents( closed_path );
+        m_treeview.set_cursor( closed_path );
+    }
+}
+
+
+
 //
 // 新スレ移行時などにスレの url と 名前を変更
 //
