@@ -62,6 +62,7 @@ namespace BOARD
         SKELETON::LabelEntry m_entry_writemail;
         Gtk::CheckButton m_check_noname; // 名無し書き込みチェック
         Gtk::Button m_bt_clear_post_history;
+        Gtk::Button m_bt_set_default_namemail;
 
         // クッキー と キーワード表示
         Gtk::Frame m_frame_cookie;
@@ -92,7 +93,10 @@ namespace BOARD
         Gtk::HBox m_hbox_max;
         SKELETON::LabelEntry m_label_max_line;
         SKELETON::LabelEntry m_label_max_byte;
-        SKELETON::LabelEntry m_entry_max_res;
+
+        // 最大レス数
+        Gtk::Label m_label_maxres;
+        SKELETON::SpinButton m_spin_maxres;
 
         SKELETON::LabelEntry m_label_last_access;
 
@@ -100,10 +104,14 @@ namespace BOARD
         SKELETON::LabelEntry m_label_modified;
         Gtk::Button m_button_clearmodified;
 
+        // samba24
         Gtk::HBox m_hbox_samba;
         SKELETON::LabelEntry m_label_samba;
         Gtk::Button m_button_clearsamba;
 
+        // 過去ログ表示
+        Gtk::CheckButton m_check_oldlog;
+
         // あぼーん
         Gtk::Notebook m_notebook_abone;
         Gtk::Label m_label_warning;
@@ -124,6 +132,8 @@ namespace BOARD
         Gtk::Label m_label_hour;
         SKELETON::SpinButton m_spin_hour;
 
+        Gtk::VBox m_vbox_abone_title;
+        Gtk::Button m_button_remove_old_title;
 
         // ローカルルール
         SKELETON::View* m_localrule;
@@ -132,15 +142,17 @@ namespace BOARD
         SKELETON::EditView m_edit_settingtxt;
 
       public:
-        Preferences( Gtk::Window* parent, const std::string& url );
+        Preferences( Gtk::Window* parent, const std::string& url, const std::string command );
         virtual ~Preferences();
 
       private:
         void slot_clear_modified();
         void slot_clear_samba();
         void slot_clear_post_history();
+        void slot_set_default_namemail();
         void slot_delete_cookie();
         void slot_check_live();
+        void slot_remove_old_title();
         void slot_switch_page( GtkNotebookPage*, guint page );
         virtual void slot_ok_clicked();
         virtual void timeout();
