@@ -46,6 +46,7 @@ namespace CONFIG
         CONF_TREE_SHOW_EXPANDERS = 1, // ツリービューにエクスパンダを表示
         CONF_TREE_LEVEL_INDENT = 0, // ツリービューのレベルインデント調整量(ピクセル)
         CONF_SCROLL_TREE = 1,       // カテゴリを開いたときにツリービューをスクロールする
+        CONF_SELECT_ITEM_SYNC = 1,  // ツリービューの選択を、表示中のビューと同期するか ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
         CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
         CONF_LEFT_SCRBAR = 0,       // スクロールバーを左に配置
         CONF_SHOW_OLDARTICLE = 0,   // スレ一覧で古いスレも表示
@@ -182,7 +183,8 @@ namespace CONFIG
 #define CONF_REF_PREFIX ">"
 
 // レスにアスキーアートがあると判定する正規表現
-#define CONF_REGEX_RES_AA "\"　 \""
+#define CONF_REGEX_RES_AA_DEFAULT "　 "
+#define CONF_REGEX_RES_AA "\"" CONF_REGEX_RES_AA_DEFAULT "\""
 
 // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
 #define CONF_PATH_CACHEROOT "~/.jd/"
