@@ -64,6 +64,9 @@ namespace CONFIG
     // カテゴリを開いたときにツリービューをスクロールする
     const bool get_scroll_tree();
 
+    // ツリービューの選択を、表示中のビューと同期するか ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
+    const int get_select_item_sync();
+
     // 各ビューと枠との間の余白
     const int get_view_margin();
 
@@ -77,6 +80,7 @@ namespace CONFIG
     const std::string& get_fontname( const int id );
     void set_fontname( const int id, const std::string& fontname );
     void reset_fonts();
+    const bool get_aafont_enabled();
 
     // レスを参照するときに前に付ける文字
     const std::string get_ref_prefix();
@@ -84,6 +88,10 @@ namespace CONFIG
     // 参照文字( ref_prefix ) の後のスペースの数
     const int ref_prefix_space();
 
+    // レスにアスキーアートがあると判定する正規表現
+    const std::string get_regex_res_aa();
+    void set_regex_res_aa( const std::string& regex );
+
     // JD ホームページのアドレス
     const std::string& get_url_jdhp();
 
@@ -92,6 +100,7 @@ namespace CONFIG
 
     // p2の認証サーバのアドレス
     const std::string& get_url_loginp2();
+    void set_url_loginp2( const std::string& url );
 
     // BEの認証サーバのアドレス
     const std::string& get_url_loginbe();
@@ -450,6 +459,12 @@ namespace CONFIG
     // タブ上でマウスホイールを回転してタブを切り替える
     const bool get_switchtab_wheel();
 
+    // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    const int get_newtab_pos();
+
+    // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
+    const int get_boardnexttab_pos();
+
     // スレビューに書き込みマークを表示するか
     const bool get_show_post_mark();
     void set_show_post_mark( const bool show );
@@ -539,6 +554,7 @@ namespace CONFIG
 
     // Ctrl+qでウィンドウを閉じない
     const bool get_disable_close();
+    void set_disable_close( const bool disable );
 
     // メニューバーを非表示にした時にダイアログを表示
     const bool get_show_hide_menubar_diag();
