@@ -7,6 +7,9 @@
 #include "controlid.h"
 #include "controlutil.h"
 
+#include "global.h"
+
+#include "config/globalconf.h"
 
 using namespace CONTROL;
 
@@ -27,7 +30,10 @@ KeyInputDiag::KeyInputDiag( Gtk::Window* parent, const std::string& url,const in
 //
 KeyDiag::KeyDiag( Gtk::Window* parent, const std::string& url, const int id, const std::string& str_motions )
     : CONTROL::MouseKeyDiag( parent, url, id, "ショートカットキー", str_motions )
-{}
+{
+    // Gtkアクセラレーションキーは、1つだけしか設定できないようにする
+    set_single( get_controlmode() == CONTROL::MODE_JDGLOBALS );
+}
 
 
 InputDiag* KeyDiag::create_inputdiag()
@@ -123,6 +129,7 @@ KeyPref::KeyPref( Gtk::Window* parent, const std::string& url )
     append_row( CONTROL::Copy );
     append_row( CONTROL::SelectAll );
     append_row( CONTROL::AppendFavorite );
+    append_row( CONTROL::PreferenceView );
 
     append_row( CONTROL::Search );
     append_row( CONTROL::SearchInvert );
@@ -192,6 +199,11 @@ KeyPref::KeyPref( Gtk::Window* parent, const std::string& url )
 
     append_row( CONTROL::LiveStartStop );
 
+    append_row( CONTROL::ShowSelectImage );
+    append_row( CONTROL::DeleteSelectImage, ITEM_NAME_SELECTDELIMG );
+    append_row( CONTROL::AboneSelectImage, ITEM_NAME_SELECTABONEIMG );
+    append_row( CONTROL::AboneSelectionRes );
+
     append_comment_row( "" );
     append_comment_row( "■ " + CONTROL::get_mode_label( CONTROL::MODE_IMAGEVIEW ) );
     append_row( CONTROL::CancelMosaic );
@@ -211,6 +223,11 @@ KeyPref::KeyPref( Gtk::Window* parent, const std::string& url )
     append_row( CONTROL::ExecWrite );
     append_row( CONTROL::FocusWrite );
     append_row( CONTROL::ToggleSage );
+
+    append_comment_row( "" );
+    append_comment_row( "■ " + CONTROL::get_mode_label( CONTROL::MODE_JDGLOBALS ) );
+    append_row( CONTROL::JDExit );
+    append_row( CONTROL::JDHelp );
 }
 
 
@@ -232,9 +249,14 @@ const std::string KeyPref::get_default_motions( const int id )
 }
 
 
-void KeyPref::set_motions( const std::string& name, const std::string& str_motions )
+void KeyPref::set_motions( const int id, const std::string& str_motions )
 {
-    CONTROL::set_keymotions( name, str_motions );
+    if( id == CONTROL::JDExit && ! str_motions.empty() ){
+        // JDExitを設定したら、2.8.6以前との互換性オプションをオフにする
+        CONFIG::set_disable_close( false );
+    }
+
+    CONTROL::set_keymotions( id, str_motions );
 }
 
 
