@@ -31,7 +31,9 @@ namespace DBIMG
         T_WRITEFAILED,
         T_NOT_FOUND,
         T_NODATA,
-        T_UNKNOWN
+
+        T_UNKNOWN,    // 画像ではない
+        T_FORCEIMAGE, // 拡張子がなくても画像として扱う
     };
 
     class Img;
