@@ -90,6 +90,9 @@ namespace DBTREE
         // 名無し書き込み不可
         bool m_check_noname;
 
+        // 過去ログも表示する
+        bool m_show_oldlog;
+
         //
         // subjectファイルのURLが "http://www.hoge2ch.net/hogeboard/subject.txt"
         // datファイルのURLが "http://www.hoge2ch.net/hogeboard/dat/12345.dat"
@@ -120,6 +123,11 @@ namespace DBTREE
         std::string m_charset;
         std::string m_name; // 板名
 
+        // dat型のurlに変換する時のquery ( url_dat()で使用する )
+        std::string m_query_dat;
+        std::string m_query_cgi;
+        std::string m_query_kako;
+
         // ローカルあぼーん情報(板内の全レス対象)
         std::list< std::string > m_list_abone_id; // あぼーんするID
         std::list< std::string > m_list_abone_name; // あぼーんする名前
@@ -228,6 +236,13 @@ namespace DBTREE
         // m_url_update_views に登録されている view に update_board コマンドを送る
         void send_update_board();
 
+        // クッキー:HAP
+        virtual const std::string get_hap(){ return std::string(); }
+        virtual void set_hap( const std::string& hap ){}
+
+        // クッキー:HAPの更新 (クッキーをセットした時に実行)
+        virtual void update_hap(){}
+
       public:
 
         BoardBase( const std::string& root, const std::string& path_board, const std::string& name );
@@ -261,7 +276,11 @@ namespace DBTREE
 
         // 名無し書き込み不可
         const bool get_check_noname() const { return m_check_noname; }
-        void set_check_noname( bool check );
+        void set_check_noname( const bool check ){ m_check_noname = check; }
+
+        // 過去ログも表示する
+        const bool get_show_oldlog() const { return m_show_oldlog; }
+        void set_show_oldlog( const bool show ){ m_show_oldlog = show; }
 
         // url がこの板のものかどうか
         virtual bool equal( const std::string& url );
@@ -278,8 +297,9 @@ namespace DBTREE
         void update_name( const std::string& name );
         const std::string& get_subjecttxt() const { return m_subjecttxt; }
 
-        // ダウンロード、書き込み時のエージェント名
-        virtual const std::string& get_agent();
+        // ユーザーエージェント
+        virtual const std::string& get_agent(); // ダウンロード用
+        virtual const std::string& get_agent_w(); // 書き込み用
 
         // ダウンロード時のプロキシ
         virtual const std::string get_proxy_host();
@@ -306,10 +326,14 @@ namespace DBTREE
         // 最大書き込みバイト数
         virtual const int message_count();
 
+        // 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
+        virtual const std::string get_unicode();
+
         // 書き込み用クッキー
         virtual const std::string cookie_for_write();
         const std::list< std::string >& list_cookies_for_write() { return m_list_cookies_for_write; }
-        void set_list_cookies_for_write( const std::list< std::string >& list_cookies ){ m_list_cookies_for_write = list_cookies; }
+        void set_list_cookies_for_write( const std::list< std::string >& list_cookies );
+        void reset_list_cookies_for_write(){ m_list_cookies_for_write.clear(); }
 
         // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )
         // 書き込み時のメッセージに付加する
@@ -331,7 +355,7 @@ namespace DBTREE
         // url がスレッドのURLで無い時はempty()が返る
         // もしurlが移転前の旧ホストのものだったら対応するarticlebaseクラスに旧ホスト名を知らせる
         // (例) url =  "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"のとき、
-        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15, num_str = 12-15
+        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15, num_str = "12-15"
         virtual const std::string url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str ); 
 
         // スレの url を read.cgi型のurlに変換
@@ -481,6 +505,10 @@ namespace DBTREE
         // 全書き込み履歴クリア
         void clear_all_post_history();
 
+        // 全スレの書き込み時間とスレ立て時間の文字列をリセット
+        void reset_all_write_date();
+        void reset_all_since_date();
+
         // 実況の秒数
         const time_t get_live_sec() const{ return m_live_sec; }
         void set_live_sec( time_t sec ){ m_live_sec = sec; }
@@ -492,18 +520,26 @@ namespace DBTREE
         const int get_number_max_res() const{ return m_number_max_res; }
         void set_number_max_res( const int number );
 
+        // datの最大サイズ(Kバイト)
+        virtual const int get_max_dat_lng() const { return 0; }
+
         // 板情報の取得
         virtual void read_info();
 
         // 情報保存
         virtual void save_info();
         
+        // 配下の全articlebaseクラスの情報保存
+        void save_articleinfo_all();
+
         // キャッシュ内のログ検索
         // ArticleBase のアドレスをリスト(list_article)にセットして返す
         // query が空の時はキャッシュにあるログを全てヒットさせる
+        // bm がtrueの時、しおりが付いている(スレ一覧でしおりを付けた or レスに一つでもしおりが付いている)スレのみを対象に検索する
         virtual void search_cache( std::vector< ArticleBase* >& list_article,
                                    const std::string& query,
                                    const bool mode_or, // 今のところ無視
+                                   const bool bm,
                                    const bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
             );
 
