@@ -217,6 +217,20 @@ void DBTREE::download_bbsmenu()
 }
 
 
+// bbsmenuの更新時間( 文字列 )
+const std::string DBTREE::get_date_modified()
+{
+    return get_root()->get_date_modified();
+}
+
+
+// bbsmenuの更新時間( time_t )
+const time_t DBTREE::get_time_modified()
+{
+    return get_root()->get_time_modified();
+}
+
+
 const std::string DBTREE::board_path( const std::string& url )
 {
     return DBTREE::get_board( url )->get_path_board();
@@ -302,6 +316,10 @@ void DBTREE::board_set_list_cookies_for_write( const std::string& url, const std
     DBTREE::get_board( url )->set_list_cookies_for_write( list_cookies );
 }
 
+void DBTREE::board_reset_list_cookies_for_write( const std::string& url )
+{
+    DBTREE::get_board( url )->reset_list_cookies_for_write();
+}
 
 const std::string DBTREE::board_keyword_for_write( const std::string& url )
 {
@@ -362,6 +380,11 @@ void DBTREE::board_download_subject( const std::string& url, const std::string&
     DBTREE::get_board( url )->download_subject( url_update_view, false );
 }
 
+void DBTREE::board_read_subject_from_cache( const std::string& url )
+{
+    DBTREE::get_board( url )->download_subject( std::string(), true );
+}
+
 const bool DBTREE::board_is_loading( const std::string& url )
 {
     return DBTREE::get_board( url )->is_loading();
@@ -431,12 +454,22 @@ const bool DBTREE::board_check_noname( const std::string& url )
     return DBTREE::get_board( url )->get_check_noname();
 }
 
-
-void DBTREE::board_set_check_noname( const std::string& url, bool check )
+void DBTREE::board_set_check_noname( const std::string& url, const bool check )
 {
     DBTREE::get_board( url )->set_check_noname( check );
 }
 
+const bool DBTREE::board_show_oldlog( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_show_oldlog();
+}
+
+void DBTREE::board_set_show_oldlog( const std::string& url, const bool show )
+{
+    DBTREE::get_board( url )->set_show_oldlog( show );
+}
+
+
 const int DBTREE::board_get_mode_local_proxy( const std::string& url )
 {
     return DBTREE::get_board( url )->get_mode_local_proxy();
@@ -541,14 +574,15 @@ void DBTREE::read_boardinfo_all()
 }
 
 void DBTREE::search_cache_all( std::vector< DBTREE::ArticleBase* >& list_article,
-                               const std::string& query, const bool mode_or, const bool& stop )
+                               const std::string& query, const bool mode_or, const bool bm, const bool& stop )
 {
-    DBTREE::get_root()->search_cache( list_article, query, mode_or, stop );
+    DBTREE::get_root()->search_cache( list_article, query, mode_or, bm, stop );
 }
 
-void DBTREE::search_cache( const std::string& url, std::vector< DBTREE::ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool& stop )
+void DBTREE::search_cache( const std::string& url, std::vector< DBTREE::ArticleBase* >& list_article, const std::string& query,
+                           const bool mode_or, const bool bm, const bool& stop )
 {
-    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, stop );
+    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, bm, stop );
 }
 
 void DBTREE::board_update_writetime( const std::string& url )
@@ -614,6 +648,12 @@ void DBTREE::board_set_number_max_res( const std::string& url, const int number
     DBTREE::get_board( url )->set_number_max_res( number );
 }
 
+// datの最大サイズ(Kバイト)
+const int DBTREE::board_get_max_dat_lng( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_max_dat_lng();
+}
+
 const time_t DBTREE::board_get_live_sec( const std::string& url )
 {
     return DBTREE::get_board( url )->get_live_sec();
@@ -687,6 +727,11 @@ const std::list< std::string >& DBTREE::get_abone_list_thread( const std::string
     return DBTREE::get_board( url )->get_abone_list_thread();
 }
 
+const std::list< std::string >& DBTREE::get_abone_list_thread_remove( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_thread_remove();
+}
+
 const std::list< std::string >& DBTREE::get_abone_list_word_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_word_thread();
@@ -723,9 +768,11 @@ void DBTREE::reset_abone_thread( const std::string& url,
                                  const std::list< std::string >& words,
                                  const std::list< std::string >& regexs,
                                  const int number,
-                                 const int hour )
+                                 const int hour,
+                                 const bool redraw
+    )
 {
-    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour );
+    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour, redraw );
 }
 
 /////////////////////////////////////////////////
@@ -751,6 +798,13 @@ const std::string DBTREE::article_key( const std::string& url )
 }
 
 
+// 移転する前のオリジナルのURL
+const std::string DBTREE::article_org_host( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_org_host();
+}
+
+
 const time_t DBTREE::article_since_time( const std::string& url )
 {
     return DBTREE::get_article( url )->get_since_time();
@@ -897,10 +951,19 @@ void DBTREE::article_clear_post_history( const std::string& url )
 }
 
 
+// ユーザーエージェント
+// ダウンロード用
 const std::string& DBTREE::get_agent( const std::string& url )
 {
     return DBTREE::get_board( url )->get_agent();
 }
+
+// 書き込み用
+const std::string& DBTREE::get_agent_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_agent_w();
+}
+
     
 const std::string DBTREE::get_proxy_host( const std::string& url )
 {
@@ -960,6 +1023,12 @@ const int DBTREE::message_count( const std::string& url )
     return DBTREE::get_board( url )->message_count();
 }
 
+// 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
+const std::string DBTREE::get_unicode( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_unicode();
+}
+
 const std::string& DBTREE::write_name( const std::string& url )
 {
     return DBTREE::get_article( url )->get_write_name();
@@ -1035,6 +1104,12 @@ bool DBTREE::article_save_dat( const std::string& url, const std::string& path_t
 }
 
 
+// 全スレ情報の保存
+void DBTREE::save_articleinfo_all()
+{
+    DBTREE::get_root()->save_articleinfo_all();
+}
+
 
 void DBTREE::article_update_writetime( const std::string& url )
 {
@@ -1055,6 +1130,18 @@ void DBTREE::update_abone_all_article()
 }
 
 
+// 全articlebaseクラスの書き込み時間とスレ立て時間の文字列をリセット
+void DBTREE::reset_all_write_date()
+{
+    DBTREE::get_root()->reset_all_write_date();
+}
+
+void DBTREE::reset_all_since_date()
+{
+    DBTREE::get_root()->reset_all_since_date();
+}
+
+
 const std::list< std::string >& DBTREE::get_abone_list_id( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_id();
@@ -1089,9 +1176,11 @@ void DBTREE::reset_abone( const std::string& url,
                           const std::list< std::string >& words,
                           const std::list< std::string >& regexs,
                           const std::vector< char >& vec_abone_res,
-                          const bool transparent, const bool chain, const bool age )
+                          const bool transparent, const bool chain, const bool age,
+                          const bool board, const bool global
+    )
 {
-    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age );
+    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age, board, global );
 }
 
 
@@ -1157,6 +1246,32 @@ void DBTREE::set_abone_age( const std::string& url, const bool set )
 }
 
 
+// 板レベルでのあぼーん
+const bool DBTREE::get_abone_board( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_board();
+}
+
+
+void DBTREE::set_abone_board( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_board( set );
+}
+
+
+// 全体レベルでのあぼーん
+const bool DBTREE::get_abone_global( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_global();
+}
+
+
+void DBTREE::set_abone_global( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_global( set );
+}
+
+
 const bool DBTREE::is_bookmarked_thread( const std::string& url )
 {
     return DBTREE::get_article( url )->is_bookmarked_thread();
