@@ -103,6 +103,7 @@ namespace DBTREE
         // 詳しくは  DrawAreaBase::draw_one_node() を参照
 
         bool image; // 画像かどうか
+        char* imglink; // 画像のURL
         DBIMG::Img* img;  // 画像データクラスへのポインタ(危険だが高速化のため直接アクセス、deleteしないこと)
     };
 
@@ -118,6 +119,7 @@ namespace DBTREE
         char* text;
         unsigned char color_text; // 色
         bool bold;
+        char fontid; // fontid.h
         
         // ヘッダ拡張情報
         HEADERINFO* headinfo;
