@@ -12,6 +12,7 @@
 #include "skeleton/loadable.h"
 
 #include "jdlib/heap.h"
+#include "jdlib/miscutil.h"
 
 #include <map>
 #include <cstring>
@@ -122,6 +123,9 @@ namespace DBTREE
         // パース用雑用変数
         NODE* m_node_previous;
 
+        // AA判定用
+        std::string m_aa_regex;
+
         // その他のエラーメッセージ
         std::string m_ext_err;
 
@@ -194,6 +198,9 @@ namespace DBTREE
         // 含まれる URL をリストにして取得
         std::list< std::string > get_urls();
 
+        // number番のレスを参照しているレス番号をリストにして取得
+        std::list< int > get_res_reference( const int number );
+
         // res_num に含まれるレスを参照しているレス番号をリストにして取得
         std::list< int > get_res_reference( const std::list< int >& res_num );
 
@@ -246,6 +253,9 @@ namespace DBTREE
         // 自分の書き込みにレスしたか
         const bool is_refer_posted( const int number );
 
+        // 書き込みマークセット
+        void set_posted( const int number, const bool set );
+
         // 書き込み履歴のリセット
         void clear_post_history();
 
@@ -290,7 +300,7 @@ namespace DBTREE
         NODE* create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
         NODE* create_node_text( const char* text, const int color_text, const bool bold = false );
         NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false );
-        NODE* create_node_youtube( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
+        NODE* create_node_thumbnail( const char* text, const int n, const char* link, const int n_link, const char* thumb, const int n_thumb, const int color_text, const bool bold );
 
         // 以下、構文解析用関数
         void add_raw_lines( char* rawines, size_t size );
@@ -315,6 +325,7 @@ namespace DBTREE
 
         const bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
         const int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link );
+        const int check_link_impl( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link, const int linktype, const int delim_pos );
 
         // あぼーんのクリア
         void clear_abone();
@@ -331,6 +342,9 @@ namespace DBTREE
         const bool check_abone_chain( const int number );
 
 
+        // number番のレスに含まれるレスアンカーをリストにして取得
+        std::list< ANCINFO* > get_res_anchors( const int number );
+
         // 参照数(num_reference)と色のクリア
         void clear_reference();
 
@@ -357,9 +371,36 @@ namespace DBTREE
         // IDノードの色も変更する
         void set_num_id_name( NODE* header, const int num_id_name, NODE* pre_id_name_header );
 
+
+        // from_number番から to_number 番までのレスのフォント判定を更新
+        void update_fontid( const int from_number, const int to_number );
+
+        // number番のレスのフォント判定を更新
+        void check_fontid( const int number );
+
+
         // http://ime.nu/ などをリンクから削除
         bool remove_imenu( char* str_link );
+
+        // 文字列中の"&amp;"を"&"に変換する
+        int convert_amp( char* text, const int n );
     };
+
+
+    //
+    // リンクが現れたかチェックして文字列を取得する関数
+    //   (引数の値は、check_link_impl()を見ること)
+    //
+    inline const int NodeTreeBase::check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link )
+    {
+        // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
+        int delim_pos = 0;
+        const int linktype = MISC::is_url_scheme( str_in, &delim_pos );
+
+        if( linktype == MISC::SCHEME_NONE ) return linktype;
+
+        return check_link_impl( str_in, lng_in, n_in, str_link, lng_link, linktype, delim_pos );
+    }
 }
 
 #endif
