@@ -24,7 +24,7 @@ namespace DBTREE
         
       public:
 
-        NodeTreeJBBS( const std::string url, const std::string& date_modified );
+        NodeTreeJBBS( const std::string& url, const std::string& date_modified );
         ~NodeTreeJBBS();
 
       protected:
