@@ -26,6 +26,7 @@ using namespace CORE;
 
 FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     : SKELETON::PrefDiag( parent, url, true, true ),
+      m_label_aafont( true, "AAレスと判定する正規表現(_R)： " ),
       m_bt_reset_font( "フォントの設定を全てデフォルトに戻す(_F)", true ),
 
       m_bt_change_color( "選択行の色を設定する(_S)", true ),
@@ -39,6 +40,7 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     // フォント設定をセット
     set_font_settings( "スレビュー", FONT_MAIN, "スレビューのフォント" );
     set_font_settings( "ポップアップ", FONT_POPUP, "ポップアップのフォント" );
+    set_font_settings( "アスキーアート", FONT_AA, "AA(スレビュー)のフォント" );
     set_font_settings( "板一覧／お気に入り", FONT_BBS, "板一覧／お気に入りのフォント" );
     set_font_settings( "スレ一覧", FONT_BOARD, "スレ一覧のフォント" );
     set_font_settings( "書き込みビュー", FONT_MESSAGE, "書き込みビューのフォント" );
@@ -69,9 +71,12 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     set_color_settings( COLOR_CHAR_AGE, "sage でないメール欄の文字色", CONF_COLOR_CHAR_AGE );
     set_color_settings( COLOR_CHAR_SELECTION, "選択範囲の文字色", CONF_COLOR_CHAR_SELECTION );
     set_color_settings( COLOR_CHAR_HIGHLIGHT, "検索結果などのハイライトの文字色", CONF_COLOR_CHAR_HIGHLIGHT );
-    set_color_settings( COLOR_CHAR_LINK, "通常のリンクや参照されていないレス番号、複数発言したIDの文字色", CONF_COLOR_CHAR_LINK );
+    set_color_settings( COLOR_CHAR_LINK, "通常のリンクの文字色", CONF_COLOR_CHAR_LINK );
+    set_color_settings( COLOR_CHAR_LINK_ID_LOW, "複数発言したIDの文字色", CONF_COLOR_CHAR_LINK_ID_LOW );
+    set_color_settings( COLOR_CHAR_LINK_ID_HIGH, "多く発言したIDの文字色", CONF_COLOR_CHAR_LINK_ID_HIGH );
+    set_color_settings( COLOR_CHAR_LINK_RES, "参照されていないレス番号の文字色", CONF_COLOR_CHAR_LINK_RES );
     set_color_settings( COLOR_CHAR_LINK_LOW, "他のレスから参照されたレス番号の文字色", CONF_COLOR_CHAR_LINK_LOW );
-    set_color_settings( COLOR_CHAR_LINK_HIGH, "参照された数が多いレス番号や多く発言したIDの文字色", CONF_COLOR_CHAR_LINK_HIGH );
+    set_color_settings( COLOR_CHAR_LINK_HIGH, "参照された数が多いレス番号の文字色", CONF_COLOR_CHAR_LINK_HIGH );
     set_color_settings( COLOR_IMG_NOCACHE, "画像として扱うリンクのうち、キャッシュされていない物の文字色", CONF_COLOR_IMG_NOCACHE );
     set_color_settings( COLOR_IMG_CACHED, "画像として扱うリンクのうち、キャッシュされている物の文字色", CONF_COLOR_IMG_CACHED );
     set_color_settings( COLOR_IMG_LOADING, "画像として扱うリンクのうち、ロード中の物の文字色", CONF_COLOR_IMG_LOADING );
@@ -141,6 +146,8 @@ void FontColorPref::pack_widget()
     m_tooltips.set_tip( m_spin_space, "スレビューにおいて行の高さを調節します( 標準は 1 )" );
     m_vbox_font.pack_start( m_hbox_space, Gtk::PACK_SHRINK, mrg/2 );
 
+    set_activate_entry( m_spin_space );
+
     // 下線位置
     m_spin_ubar.set_digits( 1 );
     m_spin_ubar.set_range( 0.1, 10.0 );
@@ -154,6 +161,15 @@ void FontColorPref::pack_widget()
     m_vbox_font.pack_start( m_hbox_ubar, Gtk::PACK_SHRINK, mrg/2 );
     m_tooltips.set_tip( m_spin_ubar, "スレビューにおいてアンカーなどの下線の位置を調節します( 標準は 1 )" );
 
+    set_activate_entry( m_spin_ubar );
+
+    // AAレスと判定する正規表現
+    m_label_aafont.set_text( CONFIG::get_regex_res_aa() );
+    m_vbox_font.pack_start( m_label_aafont, Gtk::PACK_SHRINK, mrg/2 );
+    m_tooltips.set_tip( m_label_aafont, "この正規表現に一致したレスは、アスキーアートフォントで表示します( 次に開いたスレから有効 )" );
+
+    set_activate_entry( m_label_aafont );
+
     // フォントのリセット
     m_bt_reset_font.signal_clicked().connect( sigc::mem_fun( *this, &FontColorPref::slot_reset_font ) );
     m_vbox_font.pack_end( m_bt_reset_font, Gtk::PACK_SHRINK );
@@ -234,6 +250,7 @@ void FontColorPref::slot_ok_clicked()
 
     CONFIG::set_adjust_line_space( m_spin_space.get_value() );
     CONFIG::set_adjust_underline_pos( m_spin_ubar.get_value() );
+    CONFIG::set_regex_res_aa( m_label_aafont.get_text() );
 
     CONFIG::set_strict_char_width( m_checkbutton_font.property_active() );
 
@@ -347,6 +364,7 @@ void FontColorPref::slot_reset_font()
 
     m_spin_space.set_value( CONFIG::CONF_ADJUST_LINE_SPACE );
     m_spin_ubar.set_value( CONFIG::CONF_ADJUST_UNDERLINE_POS );
+    m_label_aafont.set_text( CONF_REGEX_RES_AA_DEFAULT );
 }
 
 
