@@ -45,6 +45,12 @@ void HISTORY::append_history( const std::string& url_history, const std::string&
     get_history_manager()->append_history( url_history, url, name, type );
 }
 
+// url_history で指定した履歴の先頭を復元
+void HISTORY::restore_history( const std::string& url_history )
+{
+    get_history_manager()->restore_history( url_history );
+}
+
 
 // url_history で指定した履歴を全クリア
 void HISTORY::remove_allhistories( const std::string& url_history )
@@ -65,6 +71,8 @@ History_Manager::History_Manager()
     : m_menu_thread( NULL ),
       m_menu_board( NULL ),
       m_menu_close( NULL ),
+      m_menu_closeboard( NULL ),
+      m_menu_closeimg( NULL ),
       m_last_viewhistory( NULL )
 {
 #ifdef _DEBUG
@@ -84,8 +92,7 @@ History_Manager::~History_Manager()
     if( m_menu_thread ) delete m_menu_thread;
     if( m_menu_board ) delete m_menu_board;
     if( m_menu_close ) delete m_menu_close;
-
-    viewhistory2xml();
+    if( m_menu_closeimg ) delete m_menu_closeimg;
 
     if( m_view_histories.size() ){
         std::list< ViewHistory* >::iterator it = m_view_histories.begin();
@@ -97,24 +104,36 @@ History_Manager::~History_Manager()
 // 履歴メニュー取得
 Gtk::MenuItem* History_Manager::get_menu_thread()
 {
-    if( ! m_menu_thread ) m_menu_thread = new HistoryMenu( URL_HISTTHREADVIEW, "スレ履歴(_T)" );
+    if( ! m_menu_thread ) m_menu_thread = new HistoryMenu( URL_HISTTHREADVIEW, std::string( ITEM_NAME_HISTVIEW ) + "(_T)" );
     return m_menu_thread;
 }
 
 
 Gtk::MenuItem* History_Manager::get_menu_board()
 {
-    if( ! m_menu_board ) m_menu_board = new HistoryMenu( URL_HISTBOARDVIEW, "板履歴(_B)" );
+    if( ! m_menu_board ) m_menu_board = new HistoryMenu( URL_HISTBOARDVIEW, std::string( ITEM_NAME_HIST_BOARDVIEW ) + "(_B)" );
     return m_menu_board;
 }
 
 
 Gtk::MenuItem* History_Manager::get_menu_close()
 {
-    if( ! m_menu_close ) m_menu_close = new HistoryMenu( URL_HISTCLOSEVIEW, "最近閉じたスレ(_M)" );
+    if( ! m_menu_close ) m_menu_close = new HistoryMenu( URL_HISTCLOSEVIEW, std::string( ITEM_NAME_HIST_CLOSEVIEW ) + "(_M)" );
     return m_menu_close;
 }
 
+Gtk::MenuItem* History_Manager::get_menu_closeboard()
+{
+    if( ! m_menu_closeboard ) m_menu_closeboard = new HistoryMenu( URL_HISTCLOSEBOARDVIEW, std::string( ITEM_NAME_HIST_CLOSEBOARDVIEW ) + "(_N)" );
+    return m_menu_closeboard;
+}
+
+Gtk::MenuItem* History_Manager::get_menu_closeimg()
+{
+    if( ! m_menu_closeimg ) m_menu_closeimg = new HistoryMenu( URL_HISTCLOSEIMGVIEW, std::string( ITEM_NAME_HIST_CLOSEIMGVIEW ) + "(_I)" );
+    return m_menu_closeimg;
+}
+
 
 // url_history で指定した履歴に追加
 void History_Manager::append_history( const std::string& url_history, const std::string& url, const std::string& name, const int type )
@@ -129,7 +148,7 @@ void History_Manager::append_history( const std::string& url_history, const std:
         info.url = DBTREE::url_dat( url );
         info.name = DBTREE::article_subject( info.url );
     }
-    if( url_history == URL_HISTBOARDVIEW ){
+    if( url_history == URL_HISTBOARDVIEW || url_history == URL_HISTCLOSEBOARDVIEW ){
 
         if( type == TYPE_BOARD ){
             info.url = DBTREE::url_boardbase( url );
@@ -140,6 +159,12 @@ void History_Manager::append_history( const std::string& url_history, const std:
             info.name = name;
         }
     }
+    if( url_history == URL_HISTCLOSEIMGVIEW ){
+
+        info.url = url;
+        info.name = name;
+    }
+
 
     CORE::DATA_INFO_LIST list_info;
     list_info.push_back( info );
@@ -150,6 +175,15 @@ void History_Manager::append_history( const std::string& url_history, const std:
 }
 
 
+// url_history で指定した履歴の先頭を復元
+void History_Manager::restore_history( const std::string& url_history )
+{
+    if( url_history == URL_HISTCLOSEVIEW && m_menu_close ) m_menu_close->restore_history();
+    if( url_history == URL_HISTCLOSEBOARDVIEW && m_menu_closeboard ) m_menu_closeboard->restore_history();
+    if( url_history == URL_HISTCLOSEIMGVIEW && m_menu_closeimg ) m_menu_closeimg->restore_history();
+}
+
+
 // url_history で指定した履歴を全クリア
 void History_Manager::remove_allhistories( const std::string& url_history )
 {
@@ -163,6 +197,8 @@ void History_Manager::set_menulabel( const std::string& url_history )
     if( url_history == URL_HISTTHREADVIEW && m_menu_thread ) m_menu_thread->set_menulabel();
     if( url_history == URL_HISTBOARDVIEW && m_menu_board ) m_menu_board->set_menulabel();
     if( url_history == URL_HISTCLOSEVIEW && m_menu_close ) m_menu_close->set_menulabel();
+    if( url_history == URL_HISTCLOSEBOARDVIEW && m_menu_closeboard ) m_menu_closeboard->set_menulabel();
+    if( url_history == URL_HISTCLOSEIMGVIEW && m_menu_closeimg ) m_menu_closeimg->set_menulabel();
 }
 
 
@@ -171,7 +207,7 @@ void History_Manager::set_menulabel( const std::string& url_history )
 
 
 //
-// XML -> viewhistory 変換
+// XMLを読み込んで View履歴に変換
 //
 void History_Manager::xml2viewhistory()
 {
@@ -246,7 +282,7 @@ void History_Manager::xml2viewhistory()
 
 
 //
-// viewhistory->XML 変換
+// View履歴をXMLに変換して保存
 //
 void History_Manager::viewhistory2xml()
 {
