@@ -72,6 +72,7 @@ namespace IMAGE
         virtual void redraw_current_view();
         virtual void close_view( const std::string& url );
         virtual void close_other_views( const std::string& url );
+        virtual void restore_lasttab();
         virtual void focus_view( int page );
         virtual void focus_current_view();
         virtual void open_window();
@@ -99,6 +100,7 @@ namespace IMAGE
         void close_error_views( const std::string mode );
         void close_noerror_views();
         void reorder( const std::string& url_from, const std::string& url_to );
+        void update_status_of_all_views();
         void focus_out_all();
         void switch_img( const std::string& url );
 
