@@ -9,9 +9,11 @@
 
 #include "jdiconv.h"
 #include "miscmsg.h"
+#include "miscutil.h"
 
 #include <errno.h>
 #include <cstring>
+#include <cstdio>
 #include <cstdlib>
 
 using namespace JDLIB;
@@ -34,6 +36,20 @@ Iconv::Iconv( const std::string& coding_from, const std::string& coding_to )
         else if( coding_from == "MS932" ) m_cd = iconv_open( coding_to.c_str(), "CP932" ); 
     }
 
+    // "EUCJP-*"で失敗したら"EUCJP"で試してみる
+    if( m_cd == ( iconv_t ) - 1 && ( errno & EINVAL ) != 0 )
+    {
+        if( coding_to.find( "EUCJP-", 0 ) == 0 )
+		{
+            m_cd = iconv_open( "EUCJP//TRANSLIT", coding_from.c_str() );
+        }
+        else if( coding_from.find( "EUCJP-", 0 ) == 0 )
+		{
+            const std::string coding_to_translit = coding_to + "//TRANSLIT";
+            m_cd = iconv_open( coding_to_translit.c_str(), "EUCJP" );
+        }
+    }
+
     if( m_cd == ( iconv_t ) -1 ){
         MISC::ERRMSG( "can't open iconv coding = " + m_coding_from + " to " + coding_to );
     }
@@ -83,7 +99,7 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
         std::cout << "byte_left_out = " << byte_left_out << std::endl;
 #endif
     
-        int ret = iconv( m_cd, ( ICONV_CONST char**)&m_buf_in_tmp, &m_byte_left_in, &buf_out, &byte_left_out );
+        const int ret = iconv( m_cd, ( ICONV_CONST char**)&m_buf_in_tmp, &m_byte_left_in, &buf_out, &byte_left_out );
 
 #ifdef _DEBUG
         std::cout << "--> ret = " << ret << std::endl;
@@ -98,9 +114,9 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
             if( errno == EILSEQ ){
 
                 char str_tmp[256];
-                unsigned char code0 = *m_buf_in_tmp;
-                unsigned char code1 = *(m_buf_in_tmp+1);
-                unsigned char code2 = *(m_buf_in_tmp+2);
+                const unsigned char code0 = *m_buf_in_tmp;
+                const unsigned char code1 = *(m_buf_in_tmp+1);
+                const unsigned char code2 = *(m_buf_in_tmp+2);
 
                 if( m_coding_from == "MS932" )
                 {
@@ -133,6 +149,32 @@ const char* Iconv::convert( char* str_in, int size_in, int& size_out )
                     }
                 }
 
+                // unicode 文字からの変換失敗
+                // 数値文字参照(&#????;)形式にする
+                if( m_coding_from == "UTF-8" ){
+
+                    int byte;
+                    const int ucs2 = MISC::utf8toucs2( m_buf_in_tmp, byte );
+                    if( byte != 1 ){
+
+                        const std::string ucs2_str = MISC::itostr( ucs2 );
+#ifdef _DEBUG
+                        std::cout << "ucs2 = " << ucs2_str << " byte = " << byte << std::endl;
+#endif
+                        m_buf_in_tmp += byte;
+                        m_byte_left_in -= byte;
+
+                        *(buf_out++) = '&';
+                        *(buf_out++) = '#';
+                        memcpy( buf_out, ucs2_str.c_str(), ucs2_str.size() ); buf_out += ucs2_str.size();
+                        *(buf_out++) = ';';
+
+                        byte_left_out -= ucs2_str.size() + 3;
+
+                        continue;
+                    }
+                }
+
                 // 時々空白(0x20)で EILSEQ が出るときがあるのでもう一度トライする
                 if( code0 == 0x20 ) continue;
 
