@@ -6,8 +6,14 @@
 #include "miscmsg.h"
 
 #include <iostream>
-#include <time.h>
+#include <ctime>
 
+#ifdef _WIN32
+// not exist _r suffix functions in mingw time.h
+#include <string.h>
+#define ctime_r( _clock, _buf ) \
+        ( strcpy( (_buf), ctime( (_clock) ) ), (_buf) )
+#endif
 
 namespace MISC
 {
