@@ -8,6 +8,7 @@
 #endif
 
 #include "misctime.h"
+#include "miscmsg.h"
 
 #include <sstream>
 #include <cstdio>
@@ -16,6 +17,7 @@
 #include <vector>
 
 #ifdef _WIN32
+#include <stdlib.h>
 // not exist _r suffix functions in mingw time.h
 #define localtime_r( _clock, _result ) \
         ( *(_result) = *localtime( (_clock) ), \
@@ -61,23 +63,38 @@ const time_t MISC::datetotime( const std::string& date )
     memset( &tm_out, 0, sizeof( struct tm ) );
 
 #ifdef _WIN32
+    int rc;
+    char month[4];
+    char monthes[][4] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
+                          "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"  };
+    char tzone[4];
+    rc = sscanf(date.c_str(), "%*3s, %2d %3s %4d %2d:%2d:%2d %3s",
+                &tm_out.tm_mday, month, &tm_out.tm_year,
+                &tm_out.tm_hour, &tm_out.tm_min, &tm_out.tm_sec, tzone);
+    if ( rc != 7 )
     {
-        char month[4];
-        char monthes[][4] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
-                              "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"  };
-        if (sscanf(date.c_str(), "%*3s, %2d %3s %4d %2d:%2d:%2d",
-            &tm_out.tm_mday, month, &tm_out.tm_year,
-            &tm_out.tm_hour, &tm_out.tm_min, &tm_out.tm_sec) == 6 ) return 0;
-        for (int i=0; i<12; i++)
+        ERRMSG( "MISC::datetotime : unknown format = " + date );
+        return 0;
+    }
+    tm_out.tm_year -= 1900;
+    for (int i=0; i<12; i++)
+    {
+        if (strcasecmp(monthes[i], month) == 0)
         {
-            if (strcasecmp(monthes[i], month) == 0)
-            {
-                tm_out.tm_mon = i;
-                break;
-            }
+            tm_out.tm_mon = i;
+            break;
         }
     }
-#else
+
+    // 通常はTZにGMTが渡される
+    std::string env = "TZ=";
+    putenv( (env + tzone).c_str() );
+    tzset();
+    time_t t_ret = mktime( &tm_out );
+    putenv( "TZ=" );
+    tzset();
+
+#else // _WIN32
     // (注意) LC_TIMEが"C"でないと環境によってはstrptime()が失敗する
     std::string lcl;
     char *lcl_tmp = setlocale( LC_TIME, NULL );
@@ -90,13 +107,13 @@ const time_t MISC::datetotime( const std::string& date )
     if( ! lcl.empty() ) setlocale( LC_TIME, lcl.c_str() ); 
 
     if( ret == NULL ) return 0;
-#endif
 
 #ifdef USE_MKTIME
     time_t t_ret = mktime( &tm_out );
 #else
     time_t t_ret = timegm( &tm_out );
 #endif
+#endif // _WIN32
 
 #ifdef _DEBUG
     std::cout << "MISC::datetotime " << date << " -> " << t_ret << std::endl;
@@ -138,6 +155,12 @@ const std::string MISC::timettostr( const time_t& time_from, const int mode )
                       ( 1900 + tm_tmp.tm_year ), ( 1 + tm_tmp.tm_mon ), tm_tmp.tm_mday,
                       week[ tm_tmp.tm_wday ], tm_tmp.tm_hour, tm_tmp.tm_min, tm_tmp.tm_sec );
     }
+    else if( mode == MISC::TIME_SECOND ){
+
+        if( localtime_r( &time_from, &tm_tmp ) )
+            snprintf( str_ret, lng, "%d/%02d/%02d %02d:%02d:%02d",
+                      ( 1900 + tm_tmp.tm_year ), ( 1 + tm_tmp.tm_mon ), tm_tmp.tm_mday, tm_tmp.tm_hour, tm_tmp.tm_min, tm_tmp.tm_sec );
+    }
     else if( mode == MISC::TIME_PASSED ){
 
         const time_t tmp_t = time( NULL ) - time_from;
