@@ -226,7 +226,7 @@ void Core::slot_toggle_toolbarpos( const int pos )
     if( ! m_enable_menuslot ) return;
 
 #ifdef _DEBUG
-    std::cout << "Core::slot_toggle_toolbarpos pos = " << pos << " / " << SESSION::toolbar_pos() << std::endl;
+    std::cout << "Core::slot_toggle_toolbarpos pos = " << pos << " / " << SESSION::get_toolbar_pos() << std::endl;
 #endif
 
     if( ! SESSION::get_show_main_toolbar() ) SESSION::set_toolbar_pos( pos );
@@ -516,6 +516,17 @@ void Core::slot_setup_articleitem()
 }
 
 
+//
+// ツールバーのアイコン(ログ/スレタイ検索)の表示項目
+//
+void Core::slot_setup_searchitem()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_SEARCHITEM, "" );
+    pref->run();
+    delete pref;
+}
+
+
 //
 // ツールバーのアイコン(書き込みビュー)の表示項目
 //
@@ -549,6 +560,15 @@ void Core::slot_setup_articleitem_menu()
 }
 
 
+//
+// 板一覧のプロパティ
+//
+void Core::slot_bbslist_pref()
+{
+    BBSLIST::get_admin()->set_command( "show_preferences", URL_BBSLISTVIEW );
+}
+
+
 //
 // スレ一覧のプロパティ
 //
@@ -925,7 +945,7 @@ void Core::slot_setup_abone_thread()
 //
 void Core::slot_toggle_abone_transp_chain()
 {
-    bool status = CONFIG::get_abone_chain() & CONFIG::get_abone_transparent();
+    const bool status = CONFIG::get_abone_chain() & CONFIG::get_abone_transparent();
 
     CONFIG::set_abone_transparent( ! status );
     CONFIG::set_abone_chain( ! status );
@@ -936,6 +956,24 @@ void Core::slot_toggle_abone_transp_chain()
 }
 
 
+//
+// NG正規表現によるあぼーん時に大小と全半角文字の違いを無視する
+//
+void Core::slot_toggle_abone_icase_wchar()
+{
+    const bool status = CONFIG::get_abone_icase() & CONFIG::get_abone_wchar();
+
+    CONFIG::set_abone_icase( ! status );
+    CONFIG::set_abone_wchar( ! status );
+
+    // あぼーん情報更新
+    DBTREE::update_abone_thread();
+
+    DBTREE::update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
 // 実況設定
 void Core::slot_setup_live()
 {
@@ -1160,7 +1198,7 @@ void Core::slot_show_sidebarboard()
         && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
         ){
 
-        const std::string tab = "left";
+        const std::string tab = "true";
         const std::string mode = "";
         CORE::core_set_command( "open_sidebar_board", SESSION::get_sidebar_current_url(), tab, mode, "0" );
     }
