@@ -5,6 +5,7 @@
 
 #include "messageadmin.h"
 #include "post.h"
+#include "confirmdiag.h"
 
 #include "skeleton/msgdiag.h"
 
@@ -162,7 +163,7 @@ void Post::post_msg()
     // http://www.w3.org/TR/html401/interact/forms.html#h-17.13.4.1
     data.contenttype = "application/x-www-form-urlencoded";
 
-    data.agent = DBTREE::get_agent( m_url );
+    data.agent = DBTREE::get_agent_w( m_url );
     data.referer = DBTREE::get_write_referer( m_url );
     data.str_post = m_msg;
     data.host_proxy = DBTREE::get_proxy_host_w( m_url );
@@ -217,7 +218,7 @@ void Post::receive_finish()
     std::string charset = DBTREE::board_charset( m_url );
     JDLIB::Iconv* libiconv = new JDLIB::Iconv( charset, "UTF-8" );
     int byte_out;
-    const std::string str = libiconv->convert( m_rawdata, m_lng_rawdata, byte_out );
+    m_return_html = libiconv->convert( m_rawdata, m_lng_rawdata, byte_out );
     delete libiconv;
 
 #ifdef _DEBUG
@@ -231,7 +232,7 @@ void Post::receive_finish()
     
     // ポスト失敗
     if( get_code() != HTTP_OK
-        && ! ( get_code() == HTTP_REDIRECT && ! location().empty() ) // リダイレクトは成功(かもしれない)
+        && ! ( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() ) // リダイレクトは成功(かもしれない)
         ){
 
         m_errmsg = get_str_code();
@@ -242,6 +243,11 @@ void Post::receive_finish()
     // 以下、code == 200、 又は 302 かつ locationがセットされている(リダイレクト) の場合
 
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    bool icase = false;
+    bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
 
     std::string title;
     std::string tag_2ch;
@@ -251,18 +257,24 @@ void Post::receive_finish()
     bool ret;
 
     // タイトル
-    regex.exec( ".*<title>([^<]*)</title>.*", str, 0, true, false );
+    icase = true;
+    newline = false; // . に改行をマッチさせる
+    regex.exec( ".*<title>([^<]*)</title>.*", m_return_html, offset, icase, newline, usemigemo, wchar );
     title = MISC::remove_space( regex.str( 1 ) );
 
     // 2chタグ
-    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    regex.exec( ".*2ch_X:([^\\-]*)\\-\\->.*", m_return_html, offset, icase, newline, usemigemo, wchar );
     tag_2ch = MISC::remove_space( regex.str( 1 ) );
 
     // エラー内容を取得
 
     // 一番内側の<b>〜</b>を探して取得
+    icase = true;
+    newline = false; // . に改行をマッチさせる
     m_errmsg = std::string();
-    if( regex.exec( "([^>]|[^b]>)*<b>(([^>]|[^b]>)*)</b>.*", str, 0, true, false ) ){
+    if( regex.exec( "([^>]|[^b]>)*<b>(([^>]|[^b]>)*)</b>.*", m_return_html, offset, icase, newline, usemigemo, wchar ) ){
 
         m_errmsg = regex.str( 2 );
     }
@@ -270,13 +282,17 @@ void Post::receive_finish()
     // 2ch タグで error が返った場合
     else if( tag_2ch.find( "error" ) != std::string::npos ){
 
-        if( regex.exec( "error +-->(.*)</body>", str, 0, true, false ) ) m_errmsg = regex.str( 1 );
+        icase = true;
+        newline = false; // . に改行をマッチさせる
+        if( regex.exec( "error +-->(.*)</body>", m_return_html, offset, icase, newline, usemigemo, wchar ) ) m_errmsg = regex.str( 1 );
     }
 
     // p2 型
     else if( title.find( "error" ) != std::string::npos ){
 
-        if( regex.exec( "<h4>(.*)</h4>", str, 0, true, false ) ) m_errmsg = regex.str( 1 );
+        icase = true;
+        newline = false; // . に改行をマッチさせる
+        if( regex.exec( "<h4>(.*)</h4>", m_return_html, offset, icase, newline, usemigemo, wchar ) ) m_errmsg = regex.str( 1 );
     }
 
     if( ! m_errmsg.empty() ){
@@ -284,7 +300,9 @@ void Post::receive_finish()
         m_errmsg = MISC::replace_str( m_errmsg, "\n", "" ); 
 
         // <a 〜を取り除く
-        while( regex.exec( "(.*)<a +href *= *\"([^\"]*)\" *>(.*)</a>(.*)", m_errmsg ) ){
+        icase = false;
+        newline = true;
+        while( regex.exec( "(.*)<a +href *= *\"([^\"]*)\" *>(.*)</a>(.*)", m_errmsg, offset, icase, newline, usemigemo, wchar ) ){
             m_errmsg = regex.str( 1 ) + " " + regex.str( 2 ) + " " + regex.str( 3 ) + regex.str( 4 );
         }
 
@@ -293,8 +311,15 @@ void Post::receive_finish()
         m_errmsg= MISC::replace_str( m_errmsg, "<hr>", "\n-------------------\n" );
 
         // samba秒取得
-        if( regex.exec( "ＥＲＲＯＲ +- +593 +([0-9]+) +sec", m_errmsg ) ){
-            time_t sec = atoi( regex.str( 1 ).c_str() );
+        icase = false;
+        newline = false; // . に改行をマッチさせる
+        // Smaba24規制の場合
+        //   ＥＲＲＯＲ - 593 60 sec たたないと書けません。(1回目、8 sec しかたってない)
+        // 忍法帖規制の場合 ( samba秒だけ取得する。 )
+        //   ＥＲＲＯＲ：修行が足りません(Lv=2)。しばらくたってから投稿してください。(48 sec)
+        //   この板のsambaは samba=30 sec
+        if( regex.exec( "ＥＲＲＯＲ( +- +593 +|：.+samba=)([0-9]+) +sec", m_errmsg, offset, icase, newline, usemigemo, wchar ) ){
+            time_t sec = atoi( regex.str( 2 ).c_str() );
 #ifdef _DEBUG
             std::cout << "samba = " << sec << std::endl;
 #endif
@@ -304,19 +329,25 @@ void Post::receive_finish()
     }
 
     // 書き込み確認
-    regex.exec( ".*<font size=\\+1 color=#FF0000>([^<]*)</font>.*", str );
+    icase = false;
+    newline = true;
+    regex.exec( ".*<font size=\\+1 color=#FF0000>([^<]*)</font>.*", m_return_html, offset, icase, newline, usemigemo, wchar );
     conf = MISC::remove_space( regex.str( 1 ) );
 
     // メッセージ本文
 
     // 2ch 型
-    ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<form.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<form.*", m_return_html, offset, icase, newline, usemigemo, wchar );
 
     // 0ch 型
-    if( ! ret ) ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<input.*", str, 0, false, false );
+    icase = false;
+    newline = false; // . に改行をマッチさせる
+    if( ! ret ) ret = regex.exec( ".*</ul>.*<b>(.*)</b>.*<input.*", m_return_html, offset, icase, newline, usemigemo, wchar );
 
     msg = MISC::remove_space( regex.str( 1 ) );
-    std::list< std::string > list_cookies = SKELETON::Loadable::cookies();
+    const::std::list< std::string > list_cookies = SKELETON::Loadable::cookies();
 
 #ifdef _DEBUG
     std::cout << "TITLE: [" << title << "]\n";
@@ -325,7 +356,7 @@ void Post::receive_finish()
     std::cout << "MSG: [" << msg << "]\n";
     std::cout << "ERR: [" << m_errmsg << "]\n";
 
-    std::list< std::string >::iterator it = list_cookies.begin();
+    std::list< std::string >::const_iterator it = list_cookies.begin();
     for( ; it != list_cookies.end(); ++it ) std::cout << "cookie : [" << (*it) << "]\n";
 
     std::cout << "location: [" << location() << "]\n";
@@ -334,13 +365,16 @@ void Post::receive_finish()
     // 成功
     if( title.find( "書きこみました" ) != std::string::npos
         || tag_2ch.find( "true" ) != std::string::npos
-        || ( get_code() == HTTP_REDIRECT && ! location().empty() )  // リダイレクトされた場合
+        || ( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() )  // リダイレクトされた場合
         ){
 
 #ifdef _DEBUG
         std::cout << "write ok" << std::endl;
 #endif        
 
+        // クッキーのセット
+        DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
+
         DBTREE::article_update_writetime( m_url );
         emit_sigfin();
         return;
@@ -359,14 +393,12 @@ void Post::receive_finish()
         if( ! CONFIG::get_always_write_ok() ){
 
             std::string diagmsg = MISC::replace_str( msg, "<br>", "\n" );
-            if( diagmsg.empty() ) diagmsg = "クッキーを有功にして書き込みますか？";
+            if( diagmsg.empty() ){
+                if( m_errmsg.empty() ) diagmsg = "クッキーを有功にして書き込みますか？";
+                else diagmsg = m_errmsg;
+            }
 
-            SKELETON::MsgCheckDiag mdiag( MESSAGE::get_admin()->get_win(),
-                                          diagmsg,
-                                          "今後表示しない(常にOK)(_D)",
-                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-
-            mdiag.set_title( "書き込み確認" );
+            ConfirmDiag mdiag( m_url, diagmsg );
             const int ret = mdiag.run();
             mdiag.hide();
             if( ret != Gtk::RESPONSE_OK ){
@@ -379,16 +411,14 @@ void Post::receive_finish()
         }
 
         // 書き込み用キーワード( hana=mogera や suka=pontan など )をセット
-        DBTREE::board_analyze_keyword_for_write( m_url, str );
+        DBTREE::board_analyze_keyword_for_write( m_url, m_return_html );
 
         // 現在のメッセージにキーワードが付加されていない時は付け加える
         const std::string keyword = DBTREE::board_keyword_for_write( m_url );
         if( ! keyword.empty() && m_msg.find( keyword ) == std::string::npos ) m_msg += "&" + keyword;
 
         // クッキーのセット
-        if( list_cookies.size() ){
-            DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
-        }
+        DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
 
         ++m_count; // 永久ループ防止
         post_msg();
@@ -401,15 +431,14 @@ void Post::receive_finish()
              && ! m_subbbs && conf.find( "書き込み確認" ) != std::string::npos ){
 
         // 書き込み用キーワード( hana=mogera や suka=pontan など )をセット
-        DBTREE::board_analyze_keyword_for_write( m_url, str );
+        DBTREE::board_analyze_keyword_for_write( m_url, m_return_html );
 
         // 現在のメッセージにキーワードが付加されていない時は付け加える
         const std::string keyword = DBTREE::board_keyword_for_write( m_url );
         if( ! keyword.empty() && m_msg.find( keyword ) == std::string::npos ) m_msg += "&" + keyword;
 
         // クッキーのセット
-        if( ! SKELETON::Loadable::cookies().empty() )
-            DBTREE::board_set_list_cookies_for_write( m_url, SKELETON::Loadable::cookies() );
+        DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
 
         // subbbs.cgi にポスト先を変更してもう一回ポスト
         m_subbbs = true;
@@ -418,18 +447,18 @@ void Post::receive_finish()
         return;
     }
 
-    // その他エラー
-    else{
-        
+    // その他のエラー
+
 #ifdef _DEBUG
-        std::cout << "Error" << std::endl;
-        std::cout << m_errmsg << std::endl;
+    std::cout << "Error" << std::endl;
+    std::cout << m_errmsg << std::endl;
 #endif        
 
-        MISC::ERRMSG( str );
+    // クッキー関係のエラーの時はクッキーをセット
+    if( tag_2ch.find( "cookie" ) != std::string::npos ) DBTREE::board_set_list_cookies_for_write( m_url, list_cookies );
 
-        set_code( HTTP_ERR );
-        emit_sigfin();
-        return;
-    }
+    MISC::ERRMSG( m_return_html );
+
+    set_code( HTTP_ERR );
+    emit_sigfin();
 }
