@@ -83,6 +83,11 @@ namespace SESSION
     const bool is_quitting();
     void set_quitting( const bool quit );
 
+    // 入れ替えなどのタブ操作中
+    // ビューの再描画などを禁止する
+    const bool is_tab_operating( const std::string& url_admin );
+    void set_tab_operating( const std::string& url_admin, const bool operating );
+
     const int get_mode_pane();
     void set_mode_pane( const int mode );
     
@@ -264,6 +269,10 @@ namespace SESSION
     const std::list< bool >& get_board_locked();
     void set_board_locked( const std::list< bool >& locked );
 
+    // スレ一覧の切り替え履歴    
+    const std::list< std::string >& get_board_switchhistory();
+    void set_board_switchhistory( const std::list< std::string >& hist );
+
     // 前回閉じたときに開いていたスレタブのページ番号とURL
     const int article_page();
     void set_article_page( const int page );
@@ -274,6 +283,10 @@ namespace SESSION
     const std::list< bool >& get_article_locked();
     void set_article_locked( const std::list< bool >& locked );
 
+    // スレタブの切り替え履歴    
+    const std::list< std::string >& get_article_switchhistory();
+    void set_article_switchhistory( const std::list< std::string >& hist );
+
     // 前回閉じたときに開いていたimageのページ番号とURL
     const int image_page();
     void set_image_page( const int page );
@@ -311,6 +324,12 @@ namespace SESSION
     void set_items_article_toolbar_str( const std::string& items_str );
     const int get_item_article_toolbar( const int num );
 
+    // 検索ビューのツールバーの項目
+    const std::string& get_items_search_toolbar_str();
+    const std::string get_items_search_toolbar_default_str();
+    void set_items_search_toolbar_str( const std::string& items_str );
+    const int get_item_search_toolbar( const int num );
+
     // スレ一覧のツールバー項目
     const std::string& get_items_board_toolbar_str();
     const std::string get_items_board_toolbar_default_str();
@@ -351,6 +370,7 @@ namespace SESSION
     const int col_new();
     const int col_since();
     const int col_write();
+    const int col_access();
     const int col_speed();
     const int col_diff();
     void set_col_mark( const int width );
@@ -362,6 +382,7 @@ namespace SESSION
     void set_col_new( const int width );
     void set_col_since( const int width );
     void set_col_write( const int width );
+    void set_col_access( const int width );
     void set_col_speed( const int width );
     void set_col_diff( const int width );
 
