@@ -14,6 +14,7 @@
 #include "control/controlid.h"
 
 #include "dndmanager.h"
+#include "session.h"
 
 #include <cstring>
 
@@ -358,11 +359,11 @@ void DragableNoteBook::set_tab_fulltext( const std::string& str, const int page
 //
 // ページ取り除き
 //
-void DragableNoteBook::remove_page( int page )
+void DragableNoteBook::remove_page( const int page, const bool adjust_tab )
 {
     SKELETON::TabLabel* tablabel = m_notebook_tab.get_tablabel( page );
 
-    m_notebook_tab.remove_tab( page );
+    m_notebook_tab.remove_tab( page, adjust_tab );
     m_notebook_view.remove_page( page );
 
     if( tablabel ) delete tablabel;
@@ -445,6 +446,9 @@ void DragableNoteBook::append_toolbar( Gtk::Widget& toolbar )
 //
 void DragableNoteBook::set_current_toolbar( const int id_toolbar, SKELETON::View* view )
 {
+    // タブ操作中
+    if( SESSION::is_tab_operating( view->get_url_admin() ) ) return;
+
 #ifdef _DEBUG
     std::cout << "DragableNoteBook::set_current_toolbar id = " << id_toolbar
               << " / " << m_notebook_toolbar.get_n_pages() << std::endl
