@@ -96,18 +96,18 @@ namespace SKELETON
 
         void cursor_up_down( bool up );
 
-        bool slot_select_aamenu( GdkEventButton* event );
+        void slot_select_aamenu();
         void slot_map_popupmenu();
         void slot_hide_popupmenu();
 
         // クリップボードから引用
-        bool slot_quote_clipboard( GdkEventButton* event );
+        void slot_quote_clipboard();
 
         // 変換(スペース⇔&nbsp;)
-        bool slot_convert_space( GdkEventButton* event );
+        void slot_convert_space();
  
         // JDの動作環境を記入
-        bool slot_write_jdinfo( GdkEventButton* event );
+        void slot_write_jdinfo();
 
         // AA ポップアップ
         void slot_popup_aamenu_pos( int& x, int& y, bool& push_in );
@@ -148,6 +148,8 @@ namespace SKELETON
 #endif
         }
 
+        void set_wrap_mode( Gtk::WrapMode wrap_mode ){ m_textview.set_wrap_mode( wrap_mode ); }
+
         void modify_text( Gtk::StateType state, const Gdk::Color& color ){ m_textview.modify_text( state, color ); }
         void modify_base( Gtk::StateType state, const Gdk::Color& color ){ m_textview.modify_base( state, color ); }
 
