@@ -48,6 +48,7 @@
 
 #include <gtkmm.h>
 #include <list>
+#include <ctime>
 
 namespace JDLIB
 {
@@ -62,6 +63,8 @@ namespace SKELETON
     {
         JDLIB::Loader* m_loader;
 
+        bool m_low_priority; 
+
         // ローダからコピーしたデータ
         int m_code;
         std::string m_str_code;
@@ -91,7 +94,7 @@ namespace SKELETON
 
         const std::string& get_contenttype() const { return m_contenttype; }
 
-        std::list< std::string >& cookies() { return m_cookies; }
+        const std::list< std::string >& cookies() { return m_cookies; }
         const std::string& location() const { return m_location; }
 
         const size_t total_length() const { return m_total_length; }
@@ -118,7 +121,7 @@ namespace SKELETON
         bool start_load( const JDLIB::LOADERDATA& data );
 
         // ロード停止
-        void stop_load();
+        virtual void stop_load();
 
         // ロード強制停止
         // loadableを delete する前に terminate_load() を呼び出さないと
@@ -126,6 +129,9 @@ namespace SKELETON
         // デストラクタ内から terminate_load() しても落ちる時があるので
         // デストラクタの外から呼び出すこと
         void terminate_load();
+
+        // ローダがスレッド起動待ち状態になった時に、起動順のプライオリティを下げる
+        void set_priority_low(){ m_low_priority = true; }
         
       private:
 
