@@ -4,6 +4,7 @@
 #include "jddebug.h"
 
 #include "prefdiag.h"
+#include "label_entry.h"
 
 #include "command.h"
 #include "session.h"
@@ -12,7 +13,7 @@
 
 using namespace SKELETON;
 
-PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_cancel, const bool add_apply )
+PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_cancel, const bool add_apply, const bool add_open )
     : Gtk::Dialog(), m_url( url ), m_bt_ok( NULL ), m_bt_apply( Gtk::Stock::APPLY )
 {
     if( add_apply ){
@@ -26,7 +27,9 @@ PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_
         ->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_cancel_clicked ) );
     }
 
-    m_bt_ok = add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK );
+    if( add_open ) m_bt_ok = add_button( Gtk::Stock::OPEN, Gtk::RESPONSE_OK );
+    else m_bt_ok = add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK );
+
     m_bt_ok->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_ok_clicked ) );
 
     if( parent ) set_transient_for( *parent );
@@ -56,6 +59,31 @@ void PrefDiag::grab_ok()
 }
 
 
+//
+// Entry、LabelEntryがactiveになったときにOKでダイアログを終了させる
+//
+void PrefDiag::set_activate_entry( Gtk::Entry& entry )
+{
+    entry.signal_activate().connect( sigc::mem_fun( *this, &PrefDiag::slot_activate_entry ) );
+}
+
+void PrefDiag::set_activate_entry( LabelEntry& entry )
+{
+    entry.signal_activate().connect( sigc::mem_fun( *this, &PrefDiag::slot_activate_entry ) );
+}
+
+
+void PrefDiag::slot_activate_entry()
+{
+#ifdef _DEBUG
+    std::cout << "PrefDiag::slot_activate_entry\n";
+#endif
+
+    slot_ok_clicked();
+    response( Gtk::RESPONSE_OK );
+}
+
+
 int PrefDiag::run(){
 
     SESSION::set_dialog_shown( true );
