@@ -14,6 +14,7 @@
 #include "dndmanager.h"
 
 #include <gtk/gtk.h>
+#include "gtkmmversion.h"
 
 using namespace SKELETON;
 
@@ -22,7 +23,7 @@ using namespace SKELETON;
 // gtknotebook.c( Revision 19311, 2008-01-06 ) より引用
 //
 // gtkのバージョンが上がったときに誤動作しないかどうか注意
-// 
+//
 
 typedef enum
 {
@@ -107,15 +108,13 @@ struct _GtkNotebookPage
 const bool TabNotebook::paint( GdkEventExpose* event )
 {
     GtkNotebook *notebook = gobj();
-    if( ! notebook || ! notebook->cur_page || ! GTK_WIDGET_VISIBLE( notebook->cur_page->child ) ) return Notebook::on_expose_event( event );
+    if( ! notebook || ! notebook->cur_page || ! GTK_WIDGET_VISIBLE( notebook->cur_page->child ) ) return true;
 
     GtkWidget *widget = GTK_WIDGET( notebook );
     GdkRectangle *area = &event->area;
     const Gdk::Rectangle rect( area );
     const Glib::RefPtr< Gdk::Window > win = get_window();
 
-    widget->style->ythickness = m_ythickness;
-
     if( ! notebook->first_tab ) notebook->first_tab = notebook->children;
 
     GtkNotebookPage* page = NULL;
@@ -125,7 +124,8 @@ const bool TabNotebook::paint( GdkEventExpose* event )
     // ビュー領域の枠の描画
     m_parent->draw_box( this, event );
 
-    // タブの描画
+    // 現在のタブ以外のタブの描画
+    // 現在のタブは矢印マークを描いた後に描く
     bool show_arrow = FALSE;
     GList *children = notebook->children;
     while( children ){
@@ -137,9 +137,14 @@ const bool TabNotebook::paint( GdkEventExpose* event )
 
         if( ! GTK_WIDGET_MAPPED( page->tab_label ) ) show_arrow = TRUE;
 
-        else draw_tab( notebook, page, area, rect, win );
+        else if( page != notebook->cur_page ) draw_tab( notebook, page, area, rect, win );
     }
 
+    // gtk2.18以降？では cur_page が表示されていないのに一瞬だけ状態が visible になる時がある
+    // その時に矢印を描画すると画面にゴミが残るので描画しないようにする
+    if( show_arrow
+        && ( notebook->cur_page->allocation.width == 0 || notebook->cur_page->allocation.height == 0 ) ) show_arrow = FALSE;
+
     //矢印マーク描画
     if( show_arrow ){
 
@@ -147,6 +152,8 @@ const bool TabNotebook::paint( GdkEventExpose* event )
         draw_arrow( widget, notebook, rect, win, ARROW_RIGHT_AFTER );
     }
 
+    draw_tab( notebook, notebook->cur_page, area, rect, win );
+
     // タブの中のwidgetの描画
     children = notebook->children;
     while( children ){
@@ -160,8 +167,6 @@ const bool TabNotebook::paint( GdkEventExpose* event )
                                             page->tab_label, event );
     }
 
-    widget->style->ythickness = 0;
-
     return true;
 }
 
@@ -178,10 +183,13 @@ void TabNotebook::draw_tab( const GtkNotebook *notebook,
     GdkRectangle child_area;
     GdkRectangle page_area;
 
+    if( ! GTK_WIDGET_MAPPED( page->tab_label )
+        || page->allocation.width == 0 || page->allocation.height == 0 ) return;
+
     page_area.x = page->allocation.x;
     page_area.y = page->allocation.y;
     page_area.width = page->allocation.width;
-    page_area.height = page->allocation.height - m_ythickness;
+    page_area.height = page->allocation.height;
 
     if( gdk_rectangle_intersect( &page_area, area, &child_area ) )
     {
@@ -241,17 +249,17 @@ void TabNotebook::draw_arrow( GtkWidget *widget,
 
     if( nbarrow == ARROW_LEFT_BEFORE ) arrow = Gtk::ARROW_LEFT;
     else arrow = Gtk::ARROW_RIGHT;
- 
+
     get_style()->paint_arrow( win,
                               state_type,
-                              shadow_type, 
+                              shadow_type,
                               rect,
                               *this,
                               "notebook",
                               arrow,
                               TRUE,
                               arrow_rect.x,
-                              arrow_rect.y, 
+                              arrow_rect.y,
                               arrow_rect.width,
                               arrow_rect.height
         );
@@ -265,7 +273,7 @@ void TabNotebook::get_arrow_rect( GtkWidget *widget, const GtkNotebook *notebook
     GdkRectangle event_window_pos;
     if( get_event_window_position( widget, notebook, &event_window_pos ) ){
 
-#if GTKMMVER >= 291
+#if GTKMM_CHECK_VERSION(2,9,0)
         gtk_widget_style_get( widget,
                               "scroll-arrow-hlength", &rectangle->width,
                               "scroll-arrow-vlength", &rectangle->height,
@@ -359,15 +367,6 @@ TabNotebook::TabNotebook( DragableNoteBook* parent )
     m_tab_mrg = rcst->get_xthickness() * 2;
     if( m_tab_mrg <= 0 ) m_tab_mrg = st->get_xthickness() * 2;
 
-    m_ythickness = rcst->get_ythickness();
-    if( m_ythickness <= 0 ) m_ythickness = st->get_ythickness();
-
-    if( m_ythickness > 0 ){
-        rcst->set_ythickness( 0 );
-        modify_style( rcst );
-        property_tab_vborder() = property_tab_vborder() + m_ythickness*2;
-    }
-
     m_pre_width = get_width();
 }
 
@@ -376,11 +375,12 @@ TabNotebook::TabNotebook( DragableNoteBook* parent )
 //
 void TabNotebook::clock_in()
 {
-    // Gtk::NoteBook は configure_event()をキャッチ出来ないので
+    // Gtk::NoteBook は on_configure_event() と on_window_state_event() をキャッチ出来ない
+    // かつ、 on_size_allocate() は最大化、最小化の時に無反応なので
     // 応急処置としてタイマーの中でサイズが変更したか調べて
     // 変わっていたらタブ幅を調整する
     if( ! m_fixtab && get_n_pages() && m_pre_width != get_width()
-        && ! SESSION::is_booting() 
+        && ! SESSION::is_booting()
         && ! SESSION::is_quitting()
         ){
 
@@ -390,6 +390,17 @@ void TabNotebook::clock_in()
 }
 
 
+
+//
+// サイズ変更
+//
+void TabNotebook::on_size_allocate( Gtk::Allocation& allocation )
+{
+    clock_in(); // タブ再描画の反応を良くする
+    Gtk::Notebook::on_size_allocate( allocation );
+}
+
+
 int TabNotebook::append_tab( Widget& tab )
 {
 #ifdef _DEBUG
@@ -418,7 +429,7 @@ int TabNotebook::insert_tab( Widget& tab, int page )
 }
 
 
-void TabNotebook::remove_tab( int page )
+void TabNotebook::remove_tab( const int page, const bool adjust_tab )
 {
 #ifdef _DEBUG
     std::cout << "TabNotebook::remove_tab page = " << page << std::endl;
@@ -430,7 +441,7 @@ void TabNotebook::remove_tab( int page )
 
     if( dummypage ) delete dummypage;
 
-    adjust_tabwidth();
+    if( adjust_tab ) adjust_tabwidth();
 }
 
 
@@ -527,7 +538,7 @@ void TabNotebook::set_tab_fulltext( const std::string& str, int page )
 #endif
 
     SKELETON::TabLabel* tablabel = get_tablabel( page );
-    if( tablabel ){
+    if( tablabel && str != tablabel->get_fulltext() ){
         tablabel->set_fulltext( str );
         if( m_fixtab ) tablabel->resize_tab( str.length() );
         else adjust_tabwidth();
@@ -601,6 +612,7 @@ bool TabNotebook::adjust_tabwidth()
     SKELETON::TabLabel* tab = get_tablabel( 0 );
     if( ! tab ) return false;
     m_layout_tab->set_font_description( tab->get_label_font_description() );
+    const int label_margin = tab->get_label_margin();
 
     std::vector< int > vec_width_org; // 変更前のタブの文字数
     std::vector< int > vec_width; // 変更後のタブの文字数
@@ -610,13 +622,14 @@ bool TabNotebook::adjust_tabwidth()
     m_pre_width = get_width();
     const int width_notebook = m_pre_width - mrg_notebook;
 
-    const int avg_width_tab = (int)( (double)width_notebook / MAX( 3, pages+0.5 ) );  // タブ幅の平均値
+    const int avg_width_tab = (int)( (double)width_notebook / MAX( 3, pages ) );  // タブ幅の平均値
 
 #ifdef _DEBUG_RESIZE_TAB
     std::cout << "TabNotebook::adjust_tabwidth\n"
               << "width_notebook = " << width_notebook << " page = " << pages << std::endl
               << "avg_width_tab = " << avg_width_tab
               << " tab_mrg = " << m_tab_mrg
+              << " label_margin " << label_margin
               << std::endl;
 #endif
 
@@ -632,7 +645,7 @@ bool TabNotebook::adjust_tabwidth()
             while( vec_width[ i ] > CONFIG::get_tab_min_str() ){
 
                 m_layout_tab->set_text( LABEL_WIDTH );
-                int width = m_layout_tab->get_pixel_ink_extents().get_width() + tab->get_margin() + m_tab_mrg;
+                int width = m_layout_tab->get_pixel_logical_extents().get_width() + label_margin + m_tab_mrg;
 
 #ifdef _DEBUG_RESIZE_TAB
                 std::cout << "s " << i << " " << width << " / " << avg_width_tab
@@ -662,7 +675,7 @@ bool TabNotebook::adjust_tabwidth()
                 ++vec_width[ i ];
 
                 m_layout_tab->set_text( LABEL_WIDTH );
-                int width = m_layout_tab->get_pixel_ink_extents().get_width() + tab->get_margin() + m_tab_mrg;
+                int width = m_layout_tab->get_pixel_logical_extents().get_width() + label_margin + m_tab_mrg;
 
 #ifdef _DEBUG_RESIZE_TAB
                 std::cout << "w " << i << " " << width << " / " << avg_width_tab
@@ -677,7 +690,7 @@ bool TabNotebook::adjust_tabwidth()
             }
 
             m_layout_tab->set_text( LABEL_WIDTH );
-            width_total += ( m_layout_tab->get_pixel_ink_extents().get_width() + tab->get_margin() + m_tab_mrg );
+            width_total += ( m_layout_tab->get_pixel_logical_extents().get_width() + label_margin + m_tab_mrg );
 
             tab->resize_tab( vec_width[ i ] );
         }
@@ -703,14 +716,13 @@ void TabNotebook::get_alloc_tab( Alloc_NoteBook& alloc )
     if( notebook && notebook->cur_page ){
 
         const int bw = get_border_width();
+        const int yy = get_allocation().get_y() + bw;
         const int xx = get_allocation().get_x() + bw;
 
+        alloc.y_tab = notebook->cur_page->allocation.y - yy;
         alloc.x_tab = notebook->cur_page->allocation.x - xx;
         alloc.width_tab = notebook->cur_page->allocation.width;
-
-        // タブの高さを m_ythickness 分低くする
-        // draw_tab() を参照
-        alloc.height_tab = notebook->cur_page->allocation.height - m_ythickness; 
+        alloc.height_tab = notebook->cur_page->allocation.height;
     }
 }
 
@@ -794,11 +806,13 @@ bool TabNotebook::on_leave_notify_event( GdkEventCrossing* event )
 //
 bool TabNotebook::on_scroll_event( GdkEventScroll* event )
 {
+    if( ! CONFIG::get_switchtab_wheel() ) return true;
+
 #ifdef _DEBUG
     std::cout << "TabNotebook::scroll\n";
 #endif
 
-    m_sig_scroll_event.emit( event );
+    if( m_sig_scroll_event.emit( event ) ) return true;
 
     return Gtk::Notebook::on_scroll_event( event );
 }
