@@ -73,7 +73,7 @@ ToolBar::ToolBar( Admin* admin )
       m_button_forward( NULL )
 {
     m_buttonbar.set_border_width( 0 );
-#if GTKMMVER >= 2120
+#if GTKMM_CHECK_VERSION(2,12,0)
     m_buttonbar.set_icon_size( Gtk::ICON_SIZE_MENU );
 #endif
     m_buttonbar.set_toolbar_style( Gtk::TOOLBAR_ICONS );
@@ -279,10 +279,10 @@ void ToolBar::pack_transparent_separator()
 //
 void ToolBar::set_tooltip( Gtk::ToolItem& toolitem, const std::string& tip )
 {
-#if GTKMMVER < 2120
-    toolitem.set_tooltip( m_tooltip, tip );
-#else
+#if GTKMM_CHECK_VERSION(2,12,0)
     toolitem.set_tooltip_text( tip );
+#else
+    toolitem.set_tooltip( m_tooltip, tip );
 #endif
 }
 
@@ -350,7 +350,7 @@ Gtk::Toolbar* ToolBar::get_searchbar()
 {
     if( ! m_searchbar ){
         m_searchbar = Gtk::manage( new SKELETON::JDToolbar() );
-#if GTKMMVER >= 2120
+#if GTKMM_CHECK_VERSION(2,12,0)
         m_searchbar->set_icon_size( Gtk::ICON_SIZE_MENU );
 #endif
         m_searchbar->set_toolbar_style( Gtk::TOOLBAR_ICONS );
@@ -610,7 +610,7 @@ Gtk::ToolButton* ToolBar::get_button_clear_highlight()
 
 void ToolBar::slot_clear_highlight()
 {
-    if( ! m_enable_slot ) return;    
+    if( ! m_enable_slot ) return;
     if( m_url.empty() || ! m_admin ) return;
 
     m_admin->set_command( "clear_highlight", m_url );
@@ -647,7 +647,7 @@ Gtk::ToolItem* ToolBar::get_button_board()
 
 void ToolBar::slot_open_board()
 {
-    if( ! m_enable_slot ) return;    
+    if( ! m_enable_slot ) return;
 
     CORE::core_set_command( "open_board", DBTREE::url_subject( get_url() ), "true",
                             "auto" // オートモードで開く
