@@ -54,7 +54,7 @@ namespace SKELETON
       public:
 
         JDWindow( const bool fold_when_focusout, const bool need_mginfo = true );
-        ~JDWindow();
+        virtual ~JDWindow();
 
         Gtk::HBox& get_statbar(){ return  m_statbar; }
 
