@@ -2,6 +2,7 @@
 
 //#define _DEBUG
 #include "jddebug.h"
+#include "gtkmmversion.h"
 
 #include "usrcmdmanager.h"
 #include "command.h"
@@ -257,7 +258,7 @@ void Usrcmd_Manager::exec( const std::string command, // コマンド
     }
 
     cmd = replace_cmd( cmd, url, link, selection, number );
-       
+
 #ifdef _DEBUG
     std::cout << "exec " << cmd << std::endl;
 #endif
@@ -290,18 +291,21 @@ const bool Usrcmd_Manager::show_replacetextdiag( std::string& texti, const std::
 // コマンド置換
 // cmdの$URLをurl, $LINKをlink, $TEXT*をtext, $NUMBERをnumberで置き換えて出力
 // text は UTF-8 であること
-std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
-                                         const std::string& url,
-                                         const std::string& link,
-                                         const std::string& text,
-                                         const int number                                         
+const std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
+                                               const std::string& url,
+                                               const std::string& link,
+                                               const std::string& text,
+                                               const int number
     )
 {
     std::string cmd_out = cmd;
+    const std::string oldhostl = DBTREE::article_org_host( link );
+    const std::string oldhost = DBTREE::article_org_host( url );
 
     cmd_out = MISC::replace_str( cmd_out, "$URL", DBTREE::url_readcgi( url, 0, 0 ) );
     cmd_out = MISC::replace_str( cmd_out, "$DATURL", DBTREE::url_dat( url ) );
     cmd_out = MISC::replace_str( cmd_out, "$LOGPATH", CACHE::path_root() );
+    cmd_out = MISC::replace_str( cmd_out, "$LOCALDATL", CACHE::path_dat( link ) );
     cmd_out = MISC::replace_str( cmd_out, "$LOCALDAT", CACHE::path_dat( url ) );
     cmd_out = MISC::replace_str( cmd_out, "$LINK", link );
     cmd_out = MISC::replace_str( cmd_out, "$NUMBER", MISC::itostr( number ) );
@@ -315,12 +319,21 @@ std::string Usrcmd_Manager::replace_cmd( const std::string& cmd,
     cmd_out = MISC::replace_str( cmd_out, "$SERVER", MISC::get_hostname( url ) );
 
     // ホスト名(http://含まない)
+    cmd_out = MISC::replace_str( cmd_out, "$OLDHOSTNAMEL", MISC::get_hostname( oldhostl, false ) );
+    cmd_out = MISC::replace_str( cmd_out, "$OLDHOSTNAME", MISC::get_hostname( oldhost, false ) );
+    cmd_out = MISC::replace_str( cmd_out, "$OLDHOSTL", MISC::get_hostname( oldhostl, false ) );
+    cmd_out = MISC::replace_str( cmd_out, "$OLDHOST", MISC::get_hostname( oldhost, false ) );
     cmd_out = MISC::replace_str( cmd_out, "$HOSTNAMEL", MISC::get_hostname( link, false ) );
     cmd_out = MISC::replace_str( cmd_out, "$HOSTNAME", MISC::get_hostname( url, false ) );
     cmd_out = MISC::replace_str( cmd_out, "$HOSTL", MISC::get_hostname( link, false ) );
     cmd_out = MISC::replace_str( cmd_out, "$HOST", MISC::get_hostname( url, false ) );
 
+    // スレが属する板のID
+    cmd_out = MISC::replace_str( cmd_out, "$BBSNAMEL", DBTREE::board_id( link ) );
     cmd_out = MISC::replace_str( cmd_out, "$BBSNAME", DBTREE::board_id( url ) );
+
+    // スレのID
+    cmd_out = MISC::replace_str( cmd_out, "$DATNAMEL", DBTREE::article_key( link ) );
     cmd_out = MISC::replace_str( cmd_out, "$DATNAME", DBTREE::article_key( url ) );
 
     cmd_out = MISC::replace_str( cmd_out, "$TITLE", DBTREE::article_subject( url ) );
@@ -401,6 +414,11 @@ const bool Usrcmd_Manager::is_sensitive( int num, const std::string& link, const
         || cmd.find( "$SERVERL" ) != std::string::npos
         || cmd.find( "$HOSTNAMEL" ) != std::string::npos
         || cmd.find( "$HOSTL" ) != std::string::npos
+        || cmd.find( "$OLDHOSTNAMEL" ) != std::string::npos
+        || cmd.find( "$OLDHOSTL" ) != std::string::npos
+        || cmd.find( "$BBSNAMEL" ) != std::string::npos
+        || cmd.find( "$DATNAMEL" ) != std::string::npos
+        || cmd.find( "$LOCALDATL" ) != std::string::npos
         ){
         if( link.empty() ) return false;
     }
@@ -416,7 +434,7 @@ const bool Usrcmd_Manager::is_sensitive( int num, const std::string& link, const
         if( DBIMG::get_type_ext( link ) == DBIMG::T_UNKNOWN ) return false;
         if( ! DBIMG::is_cached( link ) ) return false;
     }
-    
+
     return true;
 }
 
@@ -441,13 +459,19 @@ const bool Usrcmd_Manager::is_hide( int num, const std::string& url )
         if( lines.size() >= 2 ){
 
             JDLIB::Regex regex;
+            const size_t offset = 0;
+            const bool icase = false;
+            const bool newline = true;
+            const bool usemigemo = false;
+            const bool wchar = false;
+
             std::list< std::string >::iterator it = lines.begin();
             ++it;
             const std::string query = *it;
 #ifdef _DEBUG
             std::cout << "query = " << query << std::endl;
 #endif
-            if( ! regex.exec( query, url ) ) return true;
+            if( ! regex.exec( query, url, offset, icase, newline, usemigemo, wchar ) ) return true;
         }
     }
 
@@ -477,7 +501,7 @@ const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionG
     std::list< XML::Dom* >::iterator it = domlist.begin();
     while( it != domlist.end() )
     {
-        if( (*it)->nodeType() == XML::NODE_TYPE_ELEMENT )    
+        if( (*it)->nodeType() == XML::NODE_TYPE_ELEMENT )
         {
 #ifdef _DEBUG
             std::cout << "name = " << (*it)->nodeName() << std::endl;
@@ -489,7 +513,7 @@ const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionG
                 const std::string name = (*it)->getAttribute( "name" );
 #ifdef _DEBUG
                 std::cout << "[" << dirno << "] " << name << std::endl;
-#endif                    
+#endif
                 const std::string dirname = "usrcmd_dir" + MISC::itostr( dirno );
                 action_group->add( Gtk::Action::create( dirname, name ) );
                 ++dirno;
@@ -509,7 +533,7 @@ const std::string Usrcmd_Manager::create_usrcmd_menu( Glib::RefPtr< Gtk::ActionG
                     const std::string name = (*it)->getAttribute( "name" );
 #ifdef _DEBUG
                     std::cout << "[" << cmdno << "] " << name << std::endl;
-#endif                    
+#endif
                     const std::string cmdname = "usrcmd" + MISC::itostr( cmdno );
                     action_group->add( Gtk::Action::create( cmdname, name ) );
                     ++cmdno;
@@ -547,7 +571,7 @@ void Usrcmd_Manager::toggle_sensitive( Glib::RefPtr< Gtk::ActionGroup >& action_
         Glib::RefPtr< Gtk::Action > act = get_action( action_group, i );
         if( act ){
 
-#if GTKMMVER >= 260
+#if GTKMM_CHECK_VERSION(2,6,0)
             if( is_hide( i, url_article ) ) act->set_visible( false );
             else{
 
@@ -563,7 +587,7 @@ void Usrcmd_Manager::toggle_sensitive( Glib::RefPtr< Gtk::ActionGroup >& action_
 #else
             if( is_sensitive( i, url_link, str_select ) ) act->set_sensitive( true );
             else act->set_sensitive( false );
-#endif            
+#endif
         }
     }
 }
